@charset "utf-8";
/* global fonts*/
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-ThinLight.ttf");
  font-weight: 100;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-ThinItalic.ttf");
  font-weight: 100;
  font-style: italic;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-ExtraLight.ttf");
  font-weight: 200;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-ExtraLightItalic.ttf");
  font-weight: 200;
  font-style: italic;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-Light.ttf");
  font-weight: 300;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-LightItalic.ttf");
  font-weight: 300;
  font-style: italic;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-Regular.ttf");
  font-weight: 400;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-Italic.ttf");
  font-weight: 400;
  font-style: italic;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-Medium.ttf");
  font-weight: 500;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-MediumItalic.ttf");
  font-weight: 500;
  font-style: italic;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-SemiBold.ttf");
  font-weight: 600;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-SemiBoldItalic.ttf");
  font-weight: 600;
  font-style: italic;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-Bold.ttf");
  font-weight: 700;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-BoldItalic.ttf");
  font-weight: 700;
  font-style: italic;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-ExtraBold.ttf");
  font-weight: 800;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-ExtraBoldItalic.ttf");
  font-weight: 800;
  font-style: italic;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-Black.ttf");
  font-weight: 900;
}
@font-face {
  font-family: "Poppins";
  src: url("./fonts/Poppins-BlackItalic.ttf");
  font-weight: 900;
  font-style: italic;
}
/* axial variables*/
/* FRAMEWORK VARIABLES */
:root {
  /* colors */
  --white: #fff;
  --whiteLight: #fffef0;
  --black: #000;
  --blackLight: #111;
  --greyLight: #f2f3f4;
  --greyDark: #232323;
  --themeColor: #E8690A;
  /* body */
  /*--body___mainFont:        "Poppins", sans-serif;*/
  --body___mainFont: "DM Sans", Arial, sans-serif;
  --body___backgroundColor: var(--white);
  --body___textColor: var(--blackLight);
  /* header */
  --header___height: 100px;
  --header___paddingH: 20px;
  --header___paddingV: 10px;
  --header___backgroundColor: var(--white);
  --header___color: var(--blackLight);
  --headerTitle___fontSize: 36px;
  --headerTitle___fontWeight: 700;
  /* header logo */
  --headerLogo___height: 20px;
  /* header nav item */
  --headerNavItem___fontSize: 21px;
  --headerNavItem___fontWeight: 600;
  --headerNavItem___marginH: 10px;
  /* footer */
  --footer___paddingH: 20px;
  --footer___paddingV: 20px;
  --footer___sectionDirection: column;
  --footer___backgroundColor: linear-gradient(36deg, #202d3a 0%, #304458 20%, #304458 80%, #202d3a 100%);
  --footer___color: var(--white);
  --footer___legalDirection: column;
  --footer___legalJustify: center;
  --footer___legalAlign: center;
  --footer___legalGap: 4px;
  --footer___anchorColor: var(--blackLight);
  --footer___anchorWeight: 500;
  --footer___anchorDecoration: none;
  /* anchor : globals anchors you can have in blog article. Apply your own styles on menu items or footer ones */
  --anchor___color: var(--themeColor);
  --anchor___weight: 500;
  --anchor___decoration: underline;
  /* main */
  --main___backgroundColor: var(--greyLight);
  --main___color: var(--blackLight);
  /* section */
  --section___paddingH: 20px;
  --section___paddingV: 20px;
  --section___paddingTopFirst: calc(var(--header___height) + var(--section___paddingV));
  /* input */
  --input___fontSize: 17px;
  --input___fontWeight: 500;
  --input___placeholderFontSize: 16px;
  --input___placeholderFontWeight: 400;
  /* components */
  --component___borderRadius: 6px;
  --container___borderRadius: 10px;
  /* charts */
  --charts___axisSize: 40px;
  /* AxialButton */
  --AxialButton___textColor: var(--white);
  --AxialButton___backgroundColor: var(--themeColor);
  --AxialButton___fontWeight: 500;
  /* AxialToggleButton */
  --AxialToggleButton___textColor: var(--white);
  --AxialToggleButton___backgroundColor: var(--themeColor);
  --AxialToggleButton___fontWeight: 500;
  /* AxialBurgerButton */
  --AxialBurgerButton___lineColor: var(--themeColor);
  --AxialBurgerButton___backgroundColor: var(--white);
  /* AxialToggleCheck */
  --AxialToggleCheck___textColor: var(--white);
  /* AxialToggleRadio */
  --AxialToggleRadio___color: var(--greyDark);
}
/* global variables */
/* axial core & application : will be probably merged */
.axial_component_base {
  display: block;
  box-sizing: border-box;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  pointer-events: all;
}
* {
  box-sizing: border-box;
}
html {
  -webkit-tap-highlight-color: transparent;
  text-shadow: none;
}
body {
  width: 100%;
  min-height: 100vh;
  margin: 0;
  padding: 0;
  overflow-x: hidden;
  overflow-y: auto;
  font-family: var(--body___mainFont);
  background-color: var(--body___backgroundColor);
  color: var(--body___textColor);
  -webkit-text-size-adjust: 100%;
  text-size-adjust: 100%;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
a {
  text-decoration: var(--anchor___decoration);
  color: var(--anchor___color);
  font-weight: var(--anchor___weight);
}
a:visited {
  text-decoration: var(--anchor___decoration);
  color: var(--body___textColor);
}
h1,
h2,
h3,
h4,
h5,
h6 {
  color: var(--body___textColor);
}
h1 {
  margin-top: 0;
  margin-bottom: 20px;
}
input {
  -webkit-user-select: text;
  user-select: text;
  appearance: none;
  outline: none;
  display: block;
  width: 100%;
  height: 42px;
  min-height: 42px;
  padding-left: 10px;
  padding-right: 10px;
  padding-top: 3px;
  padding-bottom: 4px;
  font-family: var(--body___mainFont);
  font-size: var(--input___fontSize);
  font-weight: var(--input___fontWeight);
  border-radius: var(--component___borderRadius);
  border: 2px solid var(--greyDark);
  background-color: var(--whiteLight);
}
input::placeholder {
  font-size: var(--input___placeholderFontSize);
  font-weight: var(--input___placeholderFontWeight);
}
input:disabled {
  opacity: 0.5;
}
input[type="file"] {
  height: 42px;
  min-height: 42px;
  padding: unset;
  background-color: unset;
  border: none;
  font-size: 14px;
}
input[type="file" i] {
  font-family: var(--body___mainFont);
  color: var(--body___textColor);
}
input[type="file"]::file-selector-button {
  height: 42px;
  min-height: 42px;
  cursor: pointer;
  appearance: none;
  border: none;
  outline: none;
  padding-top: 9px;
  padding-bottom: 9px;
  padding-left: 14px;
  padding-right: 14px;
  font-family: var(--body___mainFont);
  border-radius: var(--component___borderRadius);
  font-weight: var(--AxialButton___fontWeight);
  color: var(--AxialButton___textColor);
  background-color: var(--AxialButton___backgroundColor);
}
textarea {
  display: block;
  resize: none;
  outline: none;
  width: 100%;
  height: 100%;
  min-height: 200px;
  padding: 10px;
  font-family: var(--body___mainFont);
  font-size: var(--input___fontSize);
  font-weight: var(--input___fontWeight);
  border-radius: var(--component___borderRadius);
  border: 2px solid var(--greyDark);
  background-color: var(--whiteLight);
}
select {
  appearance: none;
  outline: none;
  display: block;
  width: 100%;
  height: 42px;
  padding-left: 10px;
  padding-right: 10px;
  padding-top: 3px;
  padding-bottom: 4px;
  font-family: var(--body___mainFont);
  font-size: var(--input___fontSize);
  font-weight: var(--input___fontWeight);
  border-radius: var(--component___borderRadius);
  border: 2px solid var(--themeColor);
  background-color: var(--white);
}
/* layers */
.axial_layer_base {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  pointer-events: none;
  overflow: hidden;
}
.axial_background_layer {
  background-color: transparent;
}
.axial_3d_layer {
  background-color: transparent;
}
.axial_main_layer {
  position: relative;
  min-width: 100%;
  min-height: 100vh;
  overflow: hidden;
}
.axial_intro_layer {
  z-index: 20;
}
.axial_popup_layer {
  z-index: 30;
}
.axial_medias_layer {
  z-index: 40;
}
.axial_notification_layer {
  z-index: 50;
}
.axial_overlay_layer {
  z-index: 60;
}
.axial_tooltip_layer {
  z-index: 70;
}
.axial_transition_layer {
  z-index: 999999999;
  pointer-events: all;
  transform: translateY(0%);
  transition-property: transform;
  transition-duration: 600ms;
  transition-timing-function: ease;
  background-color: var(--black);
}
/* header */
.axial_header {
  position: fixed;
  top: 0;
  width: 100%;
  height: var(--header___height);
  z-index: 10;
  color: var(--header___color);
  border-bottom: 1px solid #e1e6f0;
  transition-property: top;
  transition-duration: 500ms;
  transition-timing-function: ease;
}
.axial_header_background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: var(--header___backgroundColor);
}
.axial_header_content {
  position: absolute;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  align-items: center;
  padding-left: var(--header___paddingH);
  padding-right: var(--header___paddingH);
  padding-top: var(--header___paddingV);
  padding-bottom: var(--header___paddingV);
}
.axial_header_title {
  font-size: var(--headerTitle___fontSize);
  font-weight: var(--headerTitle___fontWeight);
}
.axial_header_logo {
  display: flex;
  height: var(--headerLogo___height);
  width: auto;
}
.axial_header_logo_svg {
  display: block;
  height: var(--headerLogo___height);
  width: auto;
}
.axial_header_logo_img {
  display: block;
  height: var(--headerLogo___height);
  width: auto;
}
.axial_header_nav {
  height: 100%;
  width: auto;
  display: none;
  flex-direction: row;
  align-items: center;
}
.axial_header_nav_item {
  display: flex;
  flex-direction: column;
  justify-content: center;
  width: auto;
  height: 100%;
  margin-left: var(--headerNavItem___marginH);
  margin-right: var(--headerNavItem___marginH);
  font-size: var(--headerNavItem___fontSize);
  font-weight: var(--headerNavItem___fontWeight);
  cursor: pointer;
}
.axial_header_nav_item:first-child {
  margin-left: 0;
}
.axial_header_nav_item:last-child {
  margin-right: 0;
}
.axial_header_nav_item-label {
  margin-bottom: 4px;
}
.axial_header_nav_item-line {
  width: 100%;
  height: 2px;
  border-radius: 1px;
  background-color: var(--white);
  transform-origin: center;
  transform: scaleX(0);
  transition-property: transform;
  transition-duration: 420ms;
  transition-timing-function: ease;
}
.axial_header_nav_item:hover .axial_header_nav_item-line {
  transform: scaleX(1);
}
.axial_header_nav_item_separator {
  margin-left: 10px;
  margin-right: 10px;
}
/* breadcrumbs */
.axial_breadcrumbs {
  padding-left: var(--section___paddingH);
  padding-right: var(--section___paddingH);
  padding-top: 6px;
  padding-bottom: 6px;
  width: 100%;
  min-height: 40px;
  height: auto;
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: flex-start;
  background-color: var(--themeColor);
}
.axial_breadcrumbs_item {
  color: var(--white);
}
.axial_breadcrumbs_link {
  color: var(--white);
  text-decoration: underline;
}
.axial_breadcrumbs_link:visited {
  color: var(--white);
  text-decoration: underline;
}
.axial_breadcrumbs_link:visited:hover {
  color: var(--white);
  text-decoration: underline;
}
.axial_breadcrumbs_separator {
  color: var(--white);
  margin-left: 10px;
  margin-right: 10px;
}
/* main */
.axial_main {
  position: relative;
  display: block;
  width: 100%;
  min-height: 100vh;
  background-color: var(--main___backgroundColor);
}
/* section */
.axial_section {
  position: relative;
  width: 100%;
  min-height: 100vh;
}
.axial_section_background {
  position: absolute;
  width: 100%;
  height: 100%;
}
.axial_section_content {
  position: relative;
  width: 100%;
  min-height: 100vh;
}
/* section utils */
.axial_section_padding-first {
  padding-top: var(--section___paddingTopFirst);
  padding-left: var(--section___paddingH);
  padding-right: var(--section___paddingH);
  padding-bottom: var(--section___paddingV);
}
.axial_section_padding {
  padding-top: var(--section___paddingV);
  padding-left: var(--section___paddingH);
  padding-right: var(--section___paddingH);
  padding-bottom: var(--section___paddingV);
}
.axial_section_temp {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  font-weight: 800;
  font-size: 48px;
}
.axial_section_subtitle {
  font-size: 18px;
  font-weight: 500;
  text-decoration: underline;
  text-transform: uppercase;
  text-align: center;
}
.axial_section_title {
  font-size: 48px;
  text-align: center;
  margin-top: 14px;
  margin-bottom: 14px;
}
.axial_section_map {
  width: 100%;
  height: 600px;
}
.axial_section_mapframe {
  width: 100%;
  height: 100%;
}
/* footer */
.axial_footer {
  position: relative;
  display: block;
  width: 100%;
  height: auto;
  color: var(--footer___color);
}
.axial_footer_background {
  position: absolute;
  width: 100%;
  height: 100%;
  background: var(--footer___backgroundColor);
  color: var(--footer___color);
}
.axial_footer_content {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  padding-left: var(--footer___paddingH);
  padding-right: var(--footer___paddingH);
}
.axial_footer_section {
  width: 100%;
  height: auto;
  display: flex;
  flex-direction: var(--footer___sectionDirection);
  justify-content: space-between;
  /*border-top: 1px solid var(--greyDark);*/
  padding-top: 40px;
  padding-bottom: 40px;
}
.axial_footer_legal {
  display: flex;
  flex-direction: var(--footer___legalDirection);
  justify-content: var(--footer___legalJustify);
  align-items: var(--footer___legalAlign);
  gap: var(--footer___legalGap);
}
.axial_footer_legal_link {
  color: var(--white);
  font-size: 14px;
  font-weight: 500;
  text-decoration: none;
}
.axial_footer_legal_link:visited {
  color: var(--white);
  font-size: 14px;
  font-weight: 500;
  text-decoration: none;
}
.axial_footer_social {
  display: flex;
  flex-direction: row;
  gap: 20px;
  justify-content: center;
}
.axial_footer_social_link {
  width: 32px;
  height: 32px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
/* utils */
.axial_spacer {
  flex-grow: 1;
}
.axial_parallax {
  will-change: transform;
  /*transform: translate3d(0, 0, 0);*/
  translate: 0px 0px;
  scale: 1;
}
/* Notifier */
/* Notifier */
.axial_notifier {
  position: absolute;
  width: 100%;
  height: 100%;
  pointer-events: none;
}
.axial_notifier_holder {
  position: absolute;
  width: 100%;
  height: auto;
  padding: 20px;
  bottom: 0px;
  transform: translateY(100%);
  transition-property: transform;
  transition-duration: 420ms;
  transition-timing-function: ease;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
}
.axial_notifier_content {
  width: 100%;
  max-width: 600px;
  height: auto;
  padding: 20px;
  min-height: 40px;
  pointer-events: all;
  color: #fff;
  background-color: rgba(0, 0, 0, 0.8);
  backdrop-filter: blur(10px);
  background-blend-mode: overlay;
  border-radius: 3px;
  box-shadow: 0px 1px 10px rgba(232, 105, 10, 0.23);
}
/* AxialInformationBar */
.axial_information_bar {
  position: fixed;
  width: 100%;
  top: 0;
  height: auto;
  z-index: 1;
  transition-property: top;
  transition-duration: 500ms;
  transition-timing-function: ease;
}
.axial_information_bar-holder {
  position: absolute;
  width: 100%;
  height: auto;
  bottom: 0;
  background-color: #028ed4;
}
.axial_information_bar-content {
  width: 100%;
  height: auto;
  color: #fff;
  font-size: 14px;
  font-weight: 600;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  padding-left: 20px;
  padding-right: 20px;
  padding-top: 6px;
  padding-bottom: 6px;
}
.axial_information_bar-closer {
  position: absolute;
  top: 0;
  right: 10px;
  width: 30px;
  height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.axial_information_bar-svg {
  cursor: pointer;
  fill: #fff;
  width: 18px;
  height: 18px;
  transform: rotate(0deg);
  transition-property: transform;
  transition-duration: 500ms;
  transition-timing-function: ease;
}
.axial_information_bar-svg:hover {
  transform: rotate(90deg);
}
/* axial aniimation */
/* POPUPS ANIMATIONS */
/* Obfuscator fader */
@keyframes axial_obfuscator_fade-in {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@keyframes axial_obfuscator_fade-out {
  from {
    opacity: 1;
  }
  to {
    opacity: 0;
  }
}
/* Popup fader */
@keyframes axial_popup_fade-in {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@keyframes axial_popup_fade-out {
  from {
    opacity: 1;
  }
  to {
    opacity: 0;
  }
}
/* Popup translate_up */
@keyframes axial_popup_translate_up-in {
  from {
    transform: translateY(100%);
  }
  to {
    transform: translateY(0%);
  }
}
@keyframes axial_popup_translate_up-out {
  from {
    transform: translateY(0%);
  }
  to {
    transform: translateY(100%);
  }
}
/* Popup translate_down */
@keyframes axial_popup_translate_down-in {
  from {
    transform: translateY(-100%);
  }
  to {
    transform: translateY(0%);
  }
}
@keyframes axial_popup_translate_down-out {
  from {
    transform: translateY(0%);
  }
  to {
    transform: translateY(-100%);
  }
}
/* Popup translate_left */
@keyframes axial_popup_translate_left-in {
  from {
    transform: translateX(100%);
  }
  to {
    transform: translateX(0%);
  }
}
@keyframes axial_popup_translate_left-out {
  from {
    transform: translateX(0%);
  }
  to {
    transform: translateX(100%);
  }
}
/* Popup translate_right */
@keyframes axial_popup_translate_right-in {
  from {
    transform: translateX(-100%);
  }
  to {
    transform: translateX(0%);
  }
}
@keyframes axial_popup_translate_right-out {
  from {
    transform: translateX(0%);
  }
  to {
    transform: translateX(-100%);
  }
}
/* Popup fade_translate_up */
@keyframes axial_popup_fade_translate_up-in {
  from {
    transform: translateY(100%);
    opacity: 0;
  }
  to {
    transform: translateY(0%);
    opacity: 1;
  }
}
@keyframes axial_popup_fade_translate_up-out {
  from {
    transform: translateY(0%);
    opacity: 1;
  }
  to {
    transform: translateY(100%);
    opacity: 0;
  }
}
/* Popup fade_translate_down */
@keyframes axial_popup_fade_translate_down-in {
  from {
    transform: translateY(-100%);
    opacity: 0;
  }
  to {
    transform: translateY(0%);
    opacity: 1;
  }
}
@keyframes axial_popup_fade_translate_down-out {
  from {
    transform: translateY(0%);
    opacity: 1;
  }
  to {
    transform: translateY(-100%);
    opacity: 0;
  }
}
/* Popup fade_translate_left */
@keyframes axial_popup_fade_translate_left-in {
  from {
    transform: translateX(100%);
    opacity: 0;
  }
  to {
    transform: translateX(0%);
    opacity: 1;
  }
}
@keyframes axial_popup_fade_translate_left-out {
  from {
    transform: translateX(0%);
    opacity: 1;
  }
  to {
    transform: translateX(100%);
    opacity: 0;
  }
}
/* Popup fade_translate_right */
@keyframes axial_popup_fade_translate_right-in {
  from {
    transform: translateX(-100%);
    opacity: 0;
  }
  to {
    transform: translateX(0%);
    opacity: 1;
  }
}
@keyframes axial_popup_fade_translate_right-out {
  from {
    transform: translateX(0%);
    opacity: 1;
  }
  to {
    transform: translateX(-100%);
    opacity: 0;
  }
}
/**/
@keyframes fade-in {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@keyframes fade-out {
  from {
    opacity: 1;
  }
  to {
    opacity: 0;
  }
}
/**/
@keyframes translate_up-in {
  from {
    transform: translateY(100%);
  }
  to {
    transform: translateY(0%);
  }
}
@keyframes translate_up-out {
  from {
    transform: translateY(0%);
  }
  to {
    transform: translateY(-100%);
  }
}
/**/
@keyframes translate_down-in {
  from {
    transform: translateY(-100%);
  }
  to {
    transform: translateY(0%);
  }
}
@keyframes translate_down-out {
  from {
    transform: translateY(0%);
  }
  to {
    transform: translateY(100%);
  }
}
/* axial components */
/* 2025 auth package */
/* AxialAuthRegister */
.axial_auth_register {
  width: 300px;
  height: auto;
  display: flex;
  flex-direction: column;
  gap: 14px;
}
.axial_auth_register-form {
  display: flex;
  flex-direction: column;
  gap: 14px;
}
.axial_auth_register-formitem {
  width: 100%;
}
.axial_auth_register-input {
  margin-top: 6px;
}
.axial_auth_register-passholder {
  margin-top: 6px;
  position: relative;
  width: 100%;
  height: 42px;
}
.axial_auth_register-password {
  position: absolute;
  width: 100%;
  height: 100%;
  padding-right: 50px;
}
.axial_auth_register-control {
  display: block;
}
.axial_auth_register-infotitle {
  font-weight: 500;
}
.axial_auth_register-info {
  padding-left: 10px;
}
.axial_auth_register-message {
  text-align: center;
}
.axial_auth_register-divider {
  width: 100%;
  height: 2px;
  background-color: #efefef;
}
.axial_auth_register-login {
  margin-top: 14px;
  text-align: center;
}
.axial_auth_register-link {
  font-weight: 600;
  text-decoration: underline;
}
.axial_auth_register-link:visited {
  font-weight: 600;
  text-decoration: underline;
}
/* AxialAuthLogin */
.axial_auth_login {
  width: 300px;
  height: auto;
  display: flex;
  flex-direction: column;
  gap: 14px;
}
.axial_auth_login-form {
  display: flex;
  flex-direction: column;
  gap: 14px;
}
.axial_auth_login-formitem {
  width: 100%;
}
.axial_auth_login-input {
  margin-top: 6px;
}
.axial_auth_login-passholder {
  margin-top: 6px;
  position: relative;
  width: 100%;
  height: 42px;
}
.axial_auth_login-password {
  position: absolute;
  width: 100%;
  height: 100%;
  padding-right: 50px;
}
.axial_auth_login-message {
  text-align: center;
}
.axial_auth_login-divider {
  width: 100%;
  height: 2px;
  background-color: #efefef;
}
.axial_auth_login-register {
  margin-top: 14px;
  text-align: center;
}
.axial_auth_login-link {
  font-weight: 600;
  text-decoration: underline;
}
.axial_auth_login-link:visited {
  font-weight: 600;
  text-decoration: underline;
}
/* AxialAuthVerifyer */
.axial_auth_verifyer {
  width: 300px;
  height: auto;
  display: flex;
  flex-direction: column;
  gap: 14px;
}
.axial_auth_verifyer-form {
  display: flex;
  flex-direction: column;
  gap: 14px;
}
.axial_auth_verifyer-baseline {
  font-weight: 400;
  text-align: center;
}
.axial_auth_verifyer-email {
  font-weight: 600;
  text-align: center;
}
.axial_auth_verifyer-inputs {
  width: 100%;
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
}
.axial_auth_verifyer-numinput {
  width: 40px;
  height: 48px;
  text-align: center;
}
.axial_auth_verifyer-message {
  text-align: center;
}
.axial_auth_verifyer-divider {
  width: 100%;
  height: 2px;
  background-color: #efefef;
}
/* SERVICE FORM 2025 */
/* AxialServiceFormItem */
.axial_service_form_item {
  position: relative;
  width: 100%;
  height: auto;
  /*
    background-color: #fff;
    border-radius: 10px;
    border: 2px solid #fff;
    */
}
.axial_service_form_item-holder {
  width: 100%;
  height: auto;
  display: flex;
  flex-direction: column;
  gap: 4px;
  /*padding: 10px;*/
}
.axial_service_form_item-header {
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
}
.axial_service_form_item-label {
  font-weight: 600;
  flex-grow: 1;
}
.axial_service_form_item-action {
  flex-shrink: 1;
}
.axial_service_form_item-info {
  font-size: 16px;
}
.axial_service_form_item-content {
  display: flex;
  flex-direction: column;
  gap: 10px;
}
.axial_service_form_item-column {
  display: flex;
  flex-direction: column;
  gap: 10px;
}
.axial_service_form_item-row {
  display: flex;
  flex-direction: row;
  gap: 10px;
}
.axial_service_form_item_image-file {
  height: 42px;
  width: 138px;
  display: flex;
  flex-direction: row;
  overflow: hidden;
}
.axial_service_form_item_image-placeholder {
  position: relative;
  display: block;
  width: 240px;
  height: 240px;
  border: 2px solid var(--greyDark);
  background-color: var(--whiteLight);
  border-radius: 6px;
  overflow: hidden;
}
.axial_service_form_item_image-image {
  display: none;
  position: absolute;
  width: 100%;
  height: 100%;
  object-fit: cover;
}
.axial_service_form_item_inputs-textarea {
  height: 90px;
  min-height: unset;
}
.axial_service_form_item-toggles {
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  gap: 14px;
}
/* AxialServiceForm */
.axial_service_form {
  position: relative;
  width: 100%;
  height: auto;
}
.axial_service_form-holder {
  position: relative;
  width: 100%;
  height: auto;
  display: flex;
  flex-direction: column;
  gap: 10px;
}
/* AxialButtonBase */
.axial_button_base {
  cursor: pointer;
}
/* AxialButton */
.axial_button {
  overflow: hidden;
  position: relative;
  width: auto;
  height: auto;
  border-radius: 3px;
  fill: #fff;
}
.axial_button-background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: var(--AxialButton___backgroundColor);
}
.axial_button-foreground {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(255, 255, 255, 0.23);
  opacity: 0;
  transition-property: opacity;
  transition-duration: 320ms;
  transition-timing-function: ease;
}
.axial_button-content {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  padding-top: 9px;
  padding-bottom: 9px;
  padding-left: 14px;
  padding-right: 14px;
}
.axial_button-label {
  width: auto;
  color: var(--AxialButton___textColor);
  font-weight: var(--AxialButton___fontWeight);
}
.axial_button-icon {
  position: relative;
}
.axial_button-icon_holder {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 18px;
  height: 18px;
}
.axial_button_icon {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 18px;
  height: 18px;
}
/* AxialToggleButton */
.axial_toggle_button {
  overflow: hidden;
  position: relative;
  width: auto;
  height: auto;
  border-radius: 3px;
  fill: #fff;
}
.axial_toggle_button-background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: var(--AxialToggleButton___backgroundColor);
}
.axial_toggle_button-foreground {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(255, 255, 255, 0.23);
  opacity: 0;
  transition-property: opacity;
  transition-duration: 320ms;
  transition-timing-function: ease;
}
.axial_toggle_button-content {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  padding-top: 9px;
  padding-bottom: 9px;
  padding-left: 14px;
  padding-right: 14px;
}
.axial_toggle_button-label {
  width: auto;
  color: var(--AxialToggleButton___textColor);
  font-weight: var(--AxialToggleButton___fontWeight);
}
.axial_toggle_button-icon {
  position: relative;
  display: block;
}
.axial_toggle_button-icontoggle {
  position: relative;
  display: none;
}
.axial_toggle_button_helper-icon_holder {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 18px;
  height: 18px;
}
/* AxialToggleCheck */
.axial_toggle_check {
  width: -moz-fit-content;
  width: fit-content;
  /*min-width: 42px;*/
  height: 42px;
  min-height: 42px;
  /*padding: 4px;*/
  display: flex;
  flex-direction: row;
  align-items: center;
}
.axial_toggle_check-border {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 24px;
  height: 24px;
  border-radius: 3px;
  background-color: rgba(255, 255, 255, 0.04);
  margin-right: 12px;
  border: solid 1px rgba(255, 255, 255, 0.08);
  flex-shrink: 0;
}
.axial_toggle_check-sign {
  display: block;
  width: 12px;
  height: 12px;
  border-radius: 1px;
  background-color: #fff;
  transform: scale(0);
  transition-property: transform;
  transition-duration: 200ms;
}
.axial_toggle_check-label {
  color: #aaa;
  text-transform: uppercase;
  letter-spacing: 2px;
  font-size: 14px;
}
/* AxialToggleRadio */
.axial_toggle_radio {
  width: -moz-fit-content;
  width: fit-content;
  height: 42px;
  min-height: 42px;
  padding: 4px;
  display: flex;
  flex-direction: row;
  align-items: center;
}
.axial_toggle_radio-border {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 24px;
  height: 24px;
  border-radius: 50%;
  background-color: var(--iceWhite);
  margin-right: 12px;
  border: solid 2px var(--black);
}
.axial_toggle_radio-circle {
  display: block;
  width: 12px;
  height: 12px;
  border-radius: 50%;
  background-color: var(--black);
  transform: scale(0);
  transition-property: transform;
  transition-duration: 200ms;
}
.axial_toggle_radio-label {
  color: var(--AxialToggleRadio___color);
}
/* AxialToggleSwitch */
.axial_toggle_switch {
  width: 46px;
  min-height: 30px;
  height: 30px;
  border-radius: 15px;
  border: 2px solid var(--white);
  padding: 4px;
  background-color: var(--black);
}
.axial_toggle_switch-circle {
  width: 18px;
  height: 18px;
  border-radius: 50%;
  border: 2px solid var(--white);
  position: relative;
  left: 0px;
  transition-property: left;
  transition-duration: 200ms;
}
/* AxialBurgerButton */
.axial_burger_button {
  position: relative;
  display: block;
  width: 48px;
  height: 48px;
  overflow: hidden;
  border-radius: var(--component___borderRadius);
  z-index: 23;
}
.axial_burger_button-background {
  position: absolute;
  width: 100%;
  height: 100%;
  overflow: hidden;
  background-color: var(--AxialBurgerButton___backgroundColor);
}
.axial_burger_button-lines {
  position: absolute;
  width: 100%;
  height: 100%;
  overflow: hidden;
}
.axial_burger_button-line {
  position: absolute;
  width: 26px;
  height: 2px;
  overflow: hidden;
  left: 11px;
  transform-origin: center;
  transition-property: top, transform;
  transition-duration: 400ms;
  transition-timing-function: ease;
  background-color: var(--AxialBurgerButton___lineColor);
}
.axial_burger_button-top {
  top: 13px;
}
.axial_burger_button-middle {
  top: 23px;
}
.axial_burger_button-bottom {
  top: 33px;
}
/* PROBABLY MISS SOMETHING ABOVE */
/* AxialTogglePasswordButton */
.axial_toggle_password_button {
  overflow: hidden;
  position: absolute;
  width: 40px;
  height: 38px;
  top: 2px;
  right: 2px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
  box-shadow: none;
  fill: #fff;
}
/* AxialTogglePanelButton */
.axial_toggle_panel_button {
  overflow: hidden;
  position: relative;
  margin-top: 8px;
  margin-bottom: 8px;
  width: auto;
  height: auto;
  border-radius: var(--component___borderRadius);
  box-shadow: none;
  fill: #627183;
}
.axial_toggle_panel_button-background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: #fff;
}
.axial_toggle_panel_button-foreground {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(218, 218, 218, 0.23);
  opacity: 0;
  transition-property: opacity;
  transition-duration: 320ms;
  transition-timing-function: linear;
}
.axial_toggle_panel_button-content {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  padding-top: 9px;
  padding-bottom: 9px;
  padding-left: 14px;
  padding-right: 14px;
}
.axial_toggle_panel_button-label {
  width: auto;
  color: #627183;
  font-size: 14px;
  font-weight: 500;
}
/* AxialAdminToggleBarButton */
.axial_admin_toggle_bar_button {
  overflow: hidden;
  position: relative;
  margin-left: 4px;
  margin-right: 4px;
  width: auto;
  height: auto;
  border-radius: var(--component___borderRadius);
  box-shadow: none;
  fill: #627183;
}
.axial_admin_toggle_bar_button-background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: #fff;
}
.axial_admin_toggle_bar_button-foreground {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(218, 218, 218, 0.23);
  opacity: 0;
  transition-property: opacity;
  transition-duration: 320ms;
  transition-timing-function: linear;
}
.axial_admin_toggle_bar_button-content {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  padding-top: 9px;
  padding-bottom: 9px;
  padding-left: 14px;
  padding-right: 14px;
}
.axial_admin_toggle_bar_button-label {
  width: auto;
  color: #627183;
  font-size: 14px;
  font-weight: 500;
}
/* AxialDropdownButton */
.axial_dropdown {
  display: inline-block;
  position: relative;
}
.axial_dropdown-holder {
  position: absolute;
  width: 100%;
  height: 0;
  top: calc(100% + 4px);
  overflow: hidden;
  transition-property: height;
  transition-duration: 600ms;
  transition-timing-function: ease;
}
.axial_dropdown-content {
  position: absolute;
  width: 100%;
  height: auto;
  bottom: 0;
}
/* AxialDropdownList */
.axial_dropdown_list-group {
  border-radius: var(--component___borderRadius);
  border: 2px solid var(--themeColor);
  background-color: var(--iceWhite);
  width: 100%;
  height: auto;
  bottom: 0;
  padding: 10px;
  display: flex;
  flex-direction: column;
  gap: 4px;
}
/* AxialDropdownCalendar */
.axial_dropdown_calendar {
  width: 300px;
}
/* AxialDropdownButton */
.axial_dropdown_button {
  position: relative;
  width: 240px;
  min-width: 240px;
}
.axial_dropdown_button-button {
  position: relative;
  cursor: pointer;
  overflow: hidden;
  width: auto;
  height: auto;
  border-radius: var(--component___borderRadius);
  fill: #fff;
  transition-property: opacity;
  transition-duration: 400ms;
  transition-timing-function: ease;
}
.axial_dropdown_button-button_background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: var(--AxialToggleButton___backgroundColor);
}
.axial_dropdown_button-button_foreground {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(218, 218, 218, 0.23);
  opacity: 0;
  transition-property: opacity;
  transition-duration: 320ms;
  transition-timing-function: linear;
}
.axial_dropdown_button-button_content {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  padding-top: 9px;
  padding-bottom: 9px;
  padding-left: 14px;
  padding-right: 14px;
}
.axial_dropdown_button-button_label {
  width: auto;
  color: var(--AxialToggleButton___textColor);
  font-weight: var(--AxialToggleButton___fontWeight);
}
.axial_dropdown_button-button_icon {
  position: relative;
  display: block;
}
.axial_dropdown_button-dropdown {
  position: absolute;
  width: 100%;
  height: 0;
  top: calc(100% + 4px);
  overflow: hidden;
  transition-property: height;
  transition-duration: 600ms;
  transition-timing-function: ease;
}
.axial_dropdown_button-dropdown_group {
  position: absolute;
  border-radius: var(--component___borderRadius);
  border: 2px solid var(--themeColor);
  background-color: var(--iceWhite);
  width: 100%;
  height: auto;
  bottom: 0;
  padding: 10px;
  display: flex;
  flex-direction: column;
  gap: 4px;
}
/* AxialDropdownToggle */
.axial_dropdown_toggle {
  overflow: hidden;
  position: relative;
  width: auto;
  height: auto;
  border-radius: var(--component___borderRadius);
  fill: #627183;
}
.axial_dropdown_toggle-background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: #fff;
}
.axial_dropdown_toggle-foreground {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(218, 218, 218, 0.23);
  opacity: 0;
  transition-property: opacity;
  transition-duration: 320ms;
  transition-timing-function: linear;
}
.axial_dropdown_toggle-content {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  padding-top: 8px;
  padding-bottom: 8px;
  padding-left: 12px;
  padding-right: 12px;
}
.axial_dropdown_toggle-label {
  width: auto;
  color: #627183;
  font-weight: 400;
  font-size: 13px;
}
.axial_dropdown_toggle-icon {
  position: relative;
  width: 0;
  height: 18px;
  margin-right: 0;
  overflow: hidden;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  transition-property: width, margin-right;
  transition-duration: 320ms;
  transition-timing-function: ease;
}
.axial_dropdown_toggle-check {
  transform: scale(0);
  width: 16px;
  height: 16px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  transition-property: transform;
  transition-duration: 320ms;
  transition-timing-function: ease;
}
/* AxialServiceButton */
.axial_service_button {
  overflow: hidden;
  position: relative;
  width: auto;
  height: 48px;
  border-radius: 9px;
  /*box-shadow: var(--AxialButton___boxShadow);*/
  fill: #fff;
}
.axial_service_button-background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: #ff6a00;
}
.axial_service_button-foreground {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(218, 218, 218, 0.23);
  opacity: 0;
  transition-property: opacity;
  transition-duration: 320ms;
  transition-timing-function: ease;
  border-radius: var(--component___borderRadius);
}
.axial_service_button-content {
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  padding-top: 9px;
  padding-bottom: 9px;
  padding-left: 14px;
  padding-right: 14px;
}
.axial_service_button-label {
  width: auto;
  color: var(--AxialButton___textColor);
  font-weight: var(--AxialButton___fontWeight);
  font-size: 20px;
}
.axial_service_button-icon {
  position: relative;
  width: 0;
  height: 22px;
  margin-right: 0;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  overflow: hidden;
  transition-property: width, margin-right;
  transition-duration: 400ms;
  transition-timing-function: ease;
}
.axial_service_button-indicator {
  width: 18px;
  height: 18px;
  border-radius: 50%;
  border-top: 3px solid #fff;
  border-left: 3px solid #fff;
  border-bottom: 3px solid #fff;
  border-right: 3px solid transparent;
}
@keyframes axialServiceButtonIndicatorAnimation {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(720deg);
  }
}
/* AxialViewerBase */
.axial_viewer_base {
  display: block;
  position: relative;
  width: 100%;
  height: 100%;
  overflow: hidden;
  touch-action: none;
}
/* AxialViewBase */
.axial_view_base {
  display: block;
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0px;
  top: 0px;
  overflow-x: hidden;
  overflow-y: auto;
}
/* AxialViewer */
.axial_viewer {
  display: block;
  position: relative;
  width: 100%;
  height: 100%;
  overflow: hidden;
  touch-action: none;
}
.axial_viewer_holder {
  display: block;
  position: absolute;
  width: 100%;
  height: 100%;
  overflow: hidden;
}
/* AxialView */
.axial_view {
  display: block;
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0px;
  top: 0px;
  overflow: hidden;
}
.axial_view_holder {
  display: block;
  position: absolute;
  width: 100%;
  height: 100%;
  overflow: hidden;
}
/* Indicator */
.axial_viewer_indicator {
  position: relative;
  width: auto;
  height: 100%;
}
.axial_viewer_indicator-holder {
  position: relative;
  width: auto;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  gap: 20px;
}
.axial_viewer_indicator-bar {
  position: absolute;
  bottom: 0;
  left: 0;
  width: 0;
  height: 3px;
  background-color: var(--themeColor);
  transition-property: left, width;
  transition-duration: 500ms;
  transition-timing-function: ease;
}
/* IndicatorStep */
.axial_viewer_indicator_step {
  position: relative;
  width: auto;
  height: 40px;
  overflow: hidden;
  border-radius: 4px;
}
.axial_viewer_indicator_step-holder {
  position: relative;
  width: auto;
  height: 100%;
}
.axial_viewer_indicator_step-content {
  width: auto;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  gap: 6px;
}
.axial_viewer_indicator_step-badge {
  width: 36px;
  height: 36px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  font-size: 21px;
  font-weight: 800;
  padding-bottom: 4px;
  border-radius: 50%;
  overflow: hidden;
  background-color: #ddd;
}
.axial_viewer_indicator_step-label {
  font-weight: 800;
  font-size: 18px;
  text-transform: uppercase;
}
.axial_loader_layer {
  position: absolute;
  left: 0px;
  right: 0px;
  top: 0px;
  bottom: 0px;
  visibility: hidden;
}
.axial_loader_background {
  position: absolute;
  left: 0px;
  right: 0px;
  top: 0px;
  bottom: 0px;
}
.axial_loader_content {
  position: absolute;
  left: 0px;
  right: 0px;
  top: 0px;
  bottom: 0px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.axial_loader_holder {
  width: 300px;
  height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  color: #000;
}
.axial_loader_icon {
  width: 40px;
  height: 40px;
  margin: 20px;
  border-radius: 50%;
  border-top: 5px solid #000;
  border-left: 5px solid #000;
  border-bottom: 5px solid #000;
  border-right: 5px solid transparent;
}
.axial_loader_number {
  width: 100%;
  font-weight: 600;
  text-align: center;
  margin-bottom: 10px;
}
.axial_loader_text {
  width: 100%;
  font-weight: 600;
  text-align: center;
}
@keyframes axial_loader_icon_animation {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}
/* NEW SHADOW */
/*
.axial_popup_layer
{
    position: absolute;
    
    left: 0px;
    right: 0px;
    bottom: 0px;
    top: 0px;
    visibility: hidden;
    overflow-x: hidden;
    overflow-y: hidden;
    pointer-events: none;
}
*/
.axial_popup_obfuscator {
  position: absolute;
  left: 0px;
  right: 0px;
  top: 0px;
  bottom: 0px;
  background-color: rgba(0, 0, 0, 0.73);
  visibility: hidden;
  opacity: 0;
  pointer-events: all;
}
.axial_popup_base {
  position: absolute;
  visibility: hidden;
  pointer-events: all;
}
.axial_popup_arrow {
  position: absolute;
  display: none;
}
/* arrow up */
.axial_popup_base_arrow-bottom {
  border-left: 10px solid transparent;
  border-right: 10px solid transparent;
  border-bottom: 10px solid #fff;
}
/* arrow down */
.axial_popup_base_arrow-top {
  border-left: 10px solid transparent;
  border-right: 10px solid transparent;
  border-top: 10px solid #fff;
}
/* arrow left */
.axial_popup_base_arrow-right {
  border-bottom: 10px solid transparent;
  border-top: 10px solid transparent;
  border-right: 10px solid #fff;
}
/* arrow right */
.axial_popup_base_arrow-left {
  border-bottom: 10px solid transparent;
  border-top: 10px solid transparent;
  border-left: 10px solid #fff;
}
/* AxialPopupBurger */
.axial_popup_burger {
  width: 300px;
  height: 100%;
  background-color: var(--white);
  padding-top: var(--header___height);
}
.ax-progress-element {
  box-sizing: border-box;
  padding: 0;
  /*overflow: hidden;*/
}
.ax-progress-bar {
  position: relative;
  height: 100%;
  box-sizing: border-box;
  transition-property: width;
  transition-duration: 800ms;
}
.ax-progress-indicator {
  position: relative;
  width: 32px;
  height: 32px;
  margin-left: -16px;
  transition-property: left;
  transition-duration: 800ms;
}
/* TOOLTIP NEW 2024 */
.axial_tooltip_base {
  position: absolute;
  visibility: hidden;
  opacity: 1;
  transform: translate(0%, 0%);
  transition-property: none;
  transition-duration: 500ms;
  transition-timing-function: ease;
  padding-left: 8px;
  padding-right: 8px;
  padding-top: 4px;
  padding-bottom: 4px;
  border: 1px solid #000;
  background-color: rgba(0, 0, 0, 0.93);
  color: var(--white);
  border-radius: 6px;
  font-size: 13px;
  font-weight: 600;
}
/* OVERLAY NEW 2024 */
.axial_overlay_base {
  position: absolute;
  visibility: hidden;
  opacity: 1;
  transform: translate(0%, 0%);
  transition-property: none;
  transition-duration: 500ms;
  transition-timing-function: ease;
}
/* AxialConsentOverlay */
.axial_consent_overlay {
  width: 300px;
  height: auto;
  padding: 20px;
  border-radius: 10px;
  border: 2px solid #fff;
  background-color: rgba(0, 0, 0, 0.83);
  -webkit-backdrop-filter: blur(10px);
  backdrop-filter: blur(10px);
}
.axial_consent_overlay-holder {
  display: flex;
  flex-direction: column;
  gap: 20px;
}
.axial_consent_overlay-header {
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  gap: 10px;
}
.axial_consent_overlay-cookie {
  flex-shrink: 0;
  width: 24px;
  height: 24px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.axial_consent_overlay-title {
  color: #fff;
  font-weight: 600;
  font-size: 18px;
}
.axial_consent_overlay-content {
  color: #fff;
}
.axial_consent_overlay-actions {
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: flex-end;
  gap: 20px;
}
/* experimental */
/* AxialCrossContainer */
.axial_cross_container {
  position: absolute;
  width: 100%;
  height: 100%;
}
.axial_cross_container_element {
  position: absolute;
  width: 100%;
  height: 100%;
}
.axial_cross_container-center {
  transform: translate(0%, 0%);
}
.axial_cross_container-top {
  transform: translate(0%, -100%);
}
.axial_cross_container-right {
  transform: translate(100%, 0%);
}
.axial_cross_container-bottom {
  transform: translate(0%, 100%);
}
.axial_cross_container-left {
  transform: translate(-100%, 0%);
}
/* AxialRateStars */
.axial_rate_stars {
  width: 200px;
  height: 34px;
}
.axial_rate_stars-holder {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
}
.axial_rate_stars-symbol {
  width: 32px;
  height: 32px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.axial_rate_stars-fill {
  fill: #fff;
}
/* AxialNavigationHelper*/
.axial_navigation_helper {
  height: 100%;
  width: auto;
}
/* Axial3DViewer : to move in a specific css */
.axial_3d_viewer {
  position: relative;
  display: block;
  width: 300px;
  height: 150px;
  min-width: 300px;
  min-height: 150px;
}
.axial_3d_viewer-full {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
.axial_3d_canvas {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
}
/* AxialAccordionElement */
.axial_accordion_element {
  position: relative;
  width: 100%;
  height: 0;
  min-width: 100px;
  transition-property: height;
  transition-duration: 400ms;
  transition-timing-function: ease;
  overflow: hidden;
}
.axial_accordion_element-content {
  width: 100%;
  height: auto;
  bottom: 0;
}
.axial_accordion_element-slot {
  width: 100%;
  height: auto;
  padding: 10px;
}
/* AxialFlipbookBase */
.axial_flipbook_base {
  position: relative;
  width: 100%;
  height: 100%;
  min-width: 300px;
  min-height: 120px;
  overflow: visible;
}
/* AxialFlipbookPageBase */
.axial_flipbook_page_base {
  position: absolute;
  left: 50%;
  width: 50%;
  height: 100%;
  display: none;
  background-color: var(--greyLight);
}
/* AxialToggleCalendarDate */
.axial_toggle_calendar_date {
  overflow: hidden;
  position: relative;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.axial_toggle_calendar_date-holder {
  position: relative;
  width: 34px;
  height: 34px;
  border-radius: 4px;
  overflow: hidden;
}
.axial_toggle_calendar_date-background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: #efefef;
  opacity: 0;
}
.axial_toggle_calendar_date-middleground {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: var(--themeColor);
  opacity: 0;
}
.axial_toggle_calendar_date-foreground {
  position: absolute;
  width: 100%;
  height: 100%;
}
.axial_toggle_calendar_date-num {
  position: absolute;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  font-weight: 500;
  font-size: 15px;
  color: #232323;
}
/* AxialCalendarGrid */
.axial_calendar_grid_base {
  width: 280px;
  height: 240px;
  display: grid;
  grid-template-columns: repeat(7, 1fr);
  grid-template-rows: repeat(6, 1fr);
  gap: 4px;
  background-color: #fff;
}
/* AxialOverlayCalendar */
.axial_overlay_calendar {
  position: absolute;
  width: 300px;
  height: 340px;
  border-radius: var(--container___borderRadius);
  overflow: hidden;
  border: 2px solid var(--themeColor);
}
/* AxialCalendar */
.axial_calendar {
  position: relative;
  width: 300px;
  height: 340px;
  border-radius: var(--container___borderRadius);
  overflow: hidden;
}
.axial_calendar-background {
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: #fff;
}
.axial_calendar-content {
  position: absolute;
  width: 100%;
  height: 100%;
  padding: 10px;
  display: flex;
  flex-direction: column;
}
.axial_calendar-header {
  width: 100%;
  height: 40px;
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 4px;
}
.axial_calendar-label {
  flex-grow: 1;
  color: #000;
  font-weight: 600;
  font-size: 16px;
  padding-left: 4px;
}
.axial_calendar-nav {
  width: 24px;
  height: 24px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  cursor: pointer;
}
.axial_calendar-days {
  width: 100%;
  height: 40px;
  display: grid;
  grid-template-columns: repeat(7, 1fr);
  grid-template-rows: 1fr;
  column-gap: 4px;
}
.axial_calendar-day {
  color: #000;
  font-size: 15px;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
}
.axial_calendar-dates {
  flex-grow: 1;
  display: grid;
  grid-template-columns: repeat(7, 1fr);
  grid-template-rows: repeat(6, 1fr);
  gap: 4px;
}
.axial_calendar-date {
  color: #000;
  font-size: 15px;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
}
/* AxialAgenda */
.axial_agenda {
  position: relative;
  width: 100%;
  height: 100%;
  overflow: hidden;
}
.axial_agenda-background {
  position: absolute;
  width: 100%;
  height: 100%;
  /*background-color: #ccc;*/
}
.axial_agenda-main {
  position: absolute;
  width: 100%;
  height: 100%;
}
.axial_agenda-header {
  width: 100%;
  height: 90px;
  top: 0;
  left: 0;
  padding-left: 40px;
  padding-right: 20px;
  padding-top: 10px;
  padding-bottom: 10px;
  display: flex;
  flex-direction: row;
  align-items: flex-start;
  gap: 4px;
  background-color: #fff;
}
.axial_agenda_header-label {
  flex-grow: 1;
  color: #000;
  font-weight: 800;
  font-size: 26px;
}
.axial_agenda_header-nav {
  margin-top: 6px;
  width: 24px;
  height: 24px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  cursor: pointer;
}
.axial_agenda-days {
  width: 100%;
  height: 60px;
  display: grid;
  grid-template-columns: 40px repeat(7, 1fr);
  grid-template-rows: 60px;
  gap: 0 0;
  border-bottom: 1px solid #ccc;
  overflow-y: scroll;
}
.axial_agenda-days::-webkit-scrollbar {
  visibility: hidden;
}
.axial_agenda-hours {
  grid-column: 1;
  grid-row: 1 / span 24;
  display: flex;
  flex-direction: column;
  justify-content: center;
}
.axial_agenda-times {
  grid-column: 1;
  grid-row: 1 / span 24;
  display: flex;
  flex-direction: column;
  justify-content: center;
}
.axial_agenda-content {
  position: absolute;
  width: 100%;
  top: 150px;
  bottom: 0;
  left: 0;
  overflow-x: hidden;
  overflow-y: auto;
}
.axial_agenda-grid {
  display: grid;
  width: 100%;
  height: auto;
  grid-template-columns: 40px repeat(7, 1fr);
  grid-template-rows: repeat(24, 60px);
  gap: 0 0;
}
/* AxialAgendaDay */
.axial_agenda_day {
  position: relative;
  height: 60px;
  background-color: #fff;
  border-left: 1px solid #ccc;
}
.axial_agenda_day-background {
  position: absolute;
  width: 100%;
  height: 100%;
}
.axial_agenda_day-content {
  position: absolute;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
  align-items: center;
}
.axial_agenda_day-dayname {
  font-size: 14px;
  font-weight: 600;
  flex-shrink: 0;
}
.axial_agenda_day-datenum {
  font-size: 24px;
  font-weight: 800;
  flex-grow: 1;
  display: flex;
  flex-direction: column;
  justify-content: center;
}
/* AxialAgendaHour */
.axial_agenda_hour {
  position: relative;
  height: 60px;
  background-color: #fff;
  border-bottom: 1px solid #fff;
}
.axial_agenda_hour-background {
  position: absolute;
}
/* AxialAgendaTime */
.axial_agenda_time {
  position: relative;
  width: 100%;
  height: 60px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  pointer-events: none;
}
.axial_agenda_time-label {
  font-size: 11px;
  font-weight: 600;
  background-color: #fff;
}
/* AxialAgendaCell */
.axial_agenda_cell {
  position: relative;
  height: 60px;
  background-color: #fff;
  border-bottom: 1px solid #ccc;
  border-left: 1px solid #ccc;
}
.axial_agenda_cell-background {
  position: absolute;
}
.axial_agenda_cell-over {
  position: absolute;
  width: 100%;
  height: 100%;
  /*background-color: rgba(3, 150, 218, 0.46);*/
}
/* AxialInfinity */
.axial_infinity {
  position: relative;
  width: 100%;
  height: 100%;
}
.axial_infinity-holder {
  position: absolute;
  width: 100%;
  height: 100%;
  perspective: 200px;
  transform-style: preserve-3d;
}
/* AxialInfinityItem */
.axial_infinity_item {
  position: absolute;
  z-index: 100;
}
.axial_infinity_item-holder {
  position: absolute;
  background-color: rgba(255, 255, 255, 0.23);
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  font-size: 40px;
  font-weight: 800;
}
/* CHARTS */
/* AxialChartElementBar */
.axial_chart_element_bar {
  position: relative;
  width: 140px;
  height: 100%;
}
.axial_chart_element_bar-holder {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  justify-content: flex-end;
  align-items: center;
}
.axial_chart_element_bar-bar {
  min-width: 40px;
  padding: 2px;
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
  text-align: center;
  height: 100%;
  overflow: hidden;
  border-radius: 3px;
  background-color: var(--themeColor);
  color: #fff;
  font-weight: 500;
}
.axial_chart_element_bar-label {
  flex-shrink: 0;
  width: 100%;
  height: 30px;
  padding-top: 4px;
  padding-left: 2px;
  padding-right: 2px;
  font-size: 12px;
  overflow: hidden;
  display: block;
  text-align: center;
  text-wrap: nowrap;
  text-overflow: ellipsis;
}
/* AxialChart */
.axial_chart {
  position: relative;
  min-width: 320px;
  min-height: 300px;
  display: flex;
  flex-direction: column;
}
.axial_chart-container {
  flex-grow: 1;
  position: relative;
  width: 100%;
  height: 100%;
}
.axial_chart-holder {
  position: absolute;
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;
  gap: 20px;
}
.axial_chart-header {
  width: 100%;
  height: 40px;
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  flex-wrap: nowrap;
  border-bottom: 1px solid var(--adminBody___borderColor);
}
.axial_chart-title {
  font-size: 18px;
  font-weight: 600;
  flex-grow: 1;
  overflow: hidden;
  text-wrap: nowrap;
  text-overflow: ellipsis;
}
.axial_chart-action {
  flex-shrink: 0;
  font-weight: 800;
}
.axial_chart-main {
  position: relative;
  width: 100%;
  flex-grow: 1;
  border-bottom: 1px solid var(--adminBody___borderColor);
}
.axial_chart-area {
  position: absolute;
  width: 100%;
  height: 100%;
}
.axial_chart-axis_area {
  position: absolute;
  left: 0;
  width: auto;
  top: 0;
  bottom: var(--charts___axisSize);
}
.axial_chart-axis_y {
  position: absolute;
  left: 0;
  width: var(--charts___axisSize);
  height: 100%;
  background-color: #f8f9fb;
}
.axial_chart-axis_scroll {
  position: absolute;
  left: var(--charts___axisSize);
  right: 0;
  height: 100%;
  overflow-x: auto;
  overflow-y: hidden;
  /*background-color: #f00;*/
}
.axial_chart-axis_x {
  position: absolute;
  background-color: #f8f9fb;
  width: auto;
  height: var(--charts___axisSize);
  left: 0;
  bottom: 0;
  /*
    left: var(--charts___axisSize);
    right: 0;
    
    bottom: 0;
    
    display: grid;
    grid-template-columns: repeat(7, 1fr);
    grid-template-rows: 100%;
    */
}
.axial_chart-step_x {
  position: absolute;
  min-width: 32px;
  height: 100%;
  padding-top: 2px;
  font-size: 12px;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
}
.axial_chart-area_row {
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
}
.axial_chart-area_column {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
/* AxialChartAverageTime */
.axial_chart_average_time-area {
  font-size: 40px;
  font-weight: 800;
}
/* AxialChartTraffic */
.axial_chart_traffic-point {
  position: absolute;
  width: 14px;
  height: 14px;
  overflow: hidden;
  border-radius: 50%;
  background-color: var(--themeColor);
  border: 2px solid #fff;
  transform: translate(-50%, 50%);
}
.axial_chart_traffic-line {
  position: absolute;
  height: 2px;
  background-color: var(--themeColor);
  transform-origin: left center;
  transform: translateY(1px);
}
.axial_chart_traffic-num {
  position: absolute;
  height: 24px;
  width: auto;
  color: #232323;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  font-size: 12px;
  padding-left: 6px;
  padding-right: 6px;
  border-radius: 2px;
  background-color: #f8f9fb;
  transform: translate(-50%, -14px);
}
.axial_chart_traffic-yline {
  position: absolute;
  height: 1px;
  width: 100%;
  background-color: #ccc;
}
.axial_chart_traffic-ynum {
  position: absolute;
  height: 24px;
  width: 32px;
  color: #f8f9fb;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  font-size: 12px;
  padding-left: 6px;
  padding-right: 6px;
  border-radius: 2px;
  background-color: #232323;
  transform: translate(0, -12px);
}
/* framework responsiveness*/
@media screen and (min-width: 768px) {
  .axial_form_utils_grid {
    display: grid;
  }
}
@media screen and (min-width: 992px) {
  .axial_header_nav {
    display: flex;
  }
}
@media screen and (min-width: 1200px) {
  :root {
    /* ADMIN */
    /* panel */
    --adminPanel___width: 320px;
    --adminPanel___transform: translateX(0);
    --adminPanel___transitionDuration: 0ms;
    --adminMain___left: 320px;
    /* header */
    --header___paddingH: 4%;
    --header___paddingV: 10px;
    /* header nav item */
    --headerNavItem___fontSize: 20px;
    /* footer */
    --footer___paddingH: 4%;
    --footer___paddingV: 0px;
    --footer___sectionDirection: row;
    --footer___legalDirection: row;
    --footer___legalJustify: center;
    --footer___legalAlign: center;
    --footer___legalGap: 20px;
    /* sections */
    --section___paddingH: 4%;
    --section___paddingV: 40px;
  }
  :root .axial_admin_burger {
    display: none;
  }
}
@media screen and (min-width: 1400px) {
  :root {
    /* header */
    --header___paddingH: 4%;
    --header___paddingV: 10px;
    /* header nav item */
    --headerNavItem___fontSize: 21px;
    /* footer */
    --footer___paddingH: 4%;
    --footer___paddingV: 0px;
    --footer___sectionDirection: row;
    /* sections */
    --section___paddingH: 4%;
    --section___paddingV: 40px;
  }
}
@media screen and (min-width: 1600px) {
  :root {
    /* header */
    --header___paddingH: 10%;
    --header___paddingV: 10px;
    /* header nav item */
    --headerNavItem___fontSize: 23px;
    /* footer */
    --footer___paddingH: 10%;
    --footer___paddingV: 0px;
    --footer___sectionDirection: row;
    /* sections */
    --section___paddingH: 10%;
    --section___paddingV: 40px;
  }
}
/* global project styles */
:root {
  --nh___global___headerActionDirection: column;
  --nh___global___headerActionJustify: flex-start;
  --nh___globals___gradient1: #f09819;
  --nh___globals___gradient2: #e97132;
  --nh___globals___gradient3: #ffc000;
  --nh___globals___darkBlue: #304458;
  --nh___globals___borderColor: #ddd;
  --nh___globals___boxShadow: rgba(100, 100, 111, 0.2) 0px 7px 29px 0px;
  --nh___globals___paddingH: 20px;
  --nh___globals___title1___fontSize: 44px;
  --nh___globals___title1___lineHeight: 58px;
  --nh___globals___title2___fontSize: 32px;
  --nh___globals___title2___lineHeight: 44px;
  --nh___globals___text___fontSize: 18px;
  --nh___globals___display: flex;
  --nh___globals___gridColumns: repeat(4, 1fr);
  --nh___globals___gridGap: 10px;
  /* footer */
  --nh___home___footerPaddingV: 40px;
  --nh___home___footerLinkAlign: center;
  --nh___home___footerSectionAlign: center;
}
.nh_bold {
  font-weight: 600;
}
.nh_italic {
  font-style: italic;
}
.nh_global_header_actions {
  height: auto;
  display: flex;
  flex-direction: var(--nh___global___headerActionDirection);
  justify-content: var(--nh___global___headerActionJustify);
  gap: 14px;
}
.nh_global_footer_actions {
  position: fixed;
  bottom: 0;
  width: 100%;
  height: 80px;
  background-color: #fff;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  gap: 10px;
  border-top: 1px solid #e1e6f0;
  padding-left: 20px;
  padding-right: 20px;
}
.nh_global_footer-withactions {
  margin-bottom: 80px;
}
.nh_button_icon {
  width: 23px;
  height: 23px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.nh_button_icon_circle {
  width: 23px;
  height: auto;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.nh_button_icon_circle_whatsapp {
  width: 26px;
  height: auto;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.nh_button_primary-icon {
  fill: #fff;
}
.nh_button_secondary-icon {
  fill: #df3f20;
}
.nh_button_primary {
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  gap: 12px;
  padding-left: 20px;
  padding-right: 20px;
  padding-top: 12px;
  padding-bottom: 12px;
  color: #fff;
  font-size: 18px;
  font-weight: 500;
  border-radius: 6px;
  overflow: hidden;
  background-size: 200% auto;
  background-image: linear-gradient(23deg, #f09819 0%, #ff512f 51%, #f09819 100%);
  background-position: right center;
  transition-property: background-position;
  transition-duration: 500ms;
  transition-timing-function: ease;
  border: 2px solid #f09819;
  text-align: center;
  text-decoration: none;
}
.nh_button_primary:hover {
  color: #fff;
  text-decoration: none;
  background-position: left center;
}
.nh_button_primary:visited {
  color: #efefef;
  text-decoration: none;
}
.nh_button_secondary {
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  gap: 12px;
  padding-left: 20px;
  padding-right: 20px;
  padding-top: 12px;
  padding-bottom: 12px;
  color: #df3f20;
  font-size: 18px;
  font-weight: 500;
  border-radius: 6px;
  overflow: hidden;
  background-color: #fff;
  transition-property: background-color;
  transition-duration: 500ms;
  transition-timing-function: ease;
  border: 2px solid #df3f20;
  text-align: center;
  text-decoration: none;
}
.nh_button_secondary:hover {
  color: #df3f20;
  text-decoration: none;
  background-color: #fff;
}
.nh_button_secondary:visited {
  color: #df3f20;
  text-decoration: none;
  background-color: #fff;
}
.nh_button_primary_whatsapp {
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  gap: 12px;
  padding-left: 20px;
  padding-right: 20px;
  padding-top: 12px;
  padding-bottom: 12px;
  color: #fff;
  font-size: 18px;
  font-weight: 500;
  border-radius: 6px;
  overflow: hidden;
  background-size: 200% auto;
  background-image: linear-gradient(23deg, #43cd66 0%, #2f8043 51%, #43cd66 100%);
  background-position: right center;
  transition-property: background-position;
  transition-duration: 500ms;
  transition-timing-function: ease;
  border: 2px solid #43cd66;
  text-align: center;
  text-decoration: none;
}
.nh_button_primary_whatsapp:hover {
  color: #fff;
  text-decoration: none;
  background-position: left center;
}
.nh_button_primary_whatsapp:visited {
  color: #efefef;
  text-decoration: none;
}
/* important */
.nh_button_footer {
  font-size: 16px;
  padding-left: 10px;
  padding-right: 10px;
  padding-top: 6px;
  padding-bottom: 6px;
  gap: 10px;
}
/* circle button */
.nh_button_primary_circle {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 64px;
  height: 64px;
  color: #efefef;
  border-radius: 50%;
  overflow: hidden;
  background-size: 200% auto;
  background-image: linear-gradient(23deg, #f09819 0%, #ff512f 51%, #f09819 100%);
  background-position: right center;
  transition: 500ms;
  border: 2px solid #f09819;
}
.nh_button_primary_circle:hover {
  color: #fff;
  text-decoration: none;
  background-position: left center;
}
.nh_button_primary_circle:visited {
  color: #efefef;
  text-decoration: none;
}
/* circle button */
.nh_button_whatsapp_circle {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  width: 64px;
  height: 64px;
  color: #efefef;
  border-radius: 50%;
  overflow: hidden;
  background-size: 200% auto;
  background-image: linear-gradient(23deg, #43cd66 0%, #2f8043 51%, #43cd66 100%);
  background-position: right center;
  transition: 500ms;
  border: 2px solid #43cd66;
}
.nh_button_whatsapp_circle:hover {
  color: #fff;
  text-decoration: none;
  background-position: left center;
}
.nh_button_whatsapp_circle:visited {
  color: #efefef;
  text-decoration: none;
}
/* */
.nh_global_title {
  font-size: var(--nh___globals___title1___fontSize);
  line-height: var(--nh___globals___title1___lineHeight);
  color: #232323;
}
.nh_global_par {
  font-size: var(--nh___globals___text___fontSize);
  color: #232323;
}
/* footer */
.nh_footer_line {
  position: relative;
  width: 200%;
  height: 60px;
  background-color: var(--nh___globals___darkBlue);
  transform: translate(-50%, 50%) rotate(-1deg);
  transform-origin: bottom center;
}
.nh_footer {
  width: 100%;
  height: auto;
  background-color: var(--nh___globals___darkBlue);
  background: linear-gradient(36deg, #202d3a 0%, #304458 20%, #304458 80%, #202d3a 100%);
  display: var(--nh___globals___display);
  flex-direction: column;
  grid-template-columns: var(--nh___globals___gridColumns);
  grid-template-rows: auto;
  gap: var(--nh___globals___gridGap);
  padding-top: var(--nh___home___footerPaddingV);
  padding-bottom: var(--nh___home___footerPaddingV);
  padding-left: var(--nh___globals___paddingH);
  padding-right: var(--nh___globals___paddingH);
  color: #fff;
}
.nh_footer_section {
  display: flex;
  flex-direction: column;
  justify-content: flex-start;
  align-items: var(--nh___home___footerSectionAlign);
  gap: 6px;
  margin-bottom: 14px;
  text-align: var(--nh___home___footerLinkAlign);
}
.nh_footer_logo {
  display: block;
  height: 50px;
}
.nh_footer_bold {
  font-weight: 700;
  margin-bottom: 10px;
}
.nh_footer_link {
  display: flex;
  flex-direction: row;
  justify-content: flex-start;
  align-items: center;
  text-decoration: none;
  color: #fff;
  font-weight: 400;
  gap: 20px;
}
.nh_footer_link:hover {
  text-decoration: none;
  color: #fff;
  font-weight: 400;
}
.nh_footer_link:visited {
  text-decoration: none;
  color: #efefef;
  font-weight: 400;
}
.nh_footer_icon {
  width: 14px;
  height: auto;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: flex-start;
  fill: #fff;
}
.nh_lateral_cta_holder {
  position: fixed;
  bottom: 40px;
  right: 20px;
  z-index: 11;
  width: 64px;
  height: 140px;
  display: none;
  flex-direction: column;
  justify-content: space-between;
  align-items: flex-end;
}
/* gradient */
.nh_global_gradient_holder {
  position: absolute;
  width: 300%;
  height: 600px;
  top: -400px;
  left: -100%;
  transform: rotate(-10deg);
  overflow: hidden;
}
.nh_global_gradient_holder_mini {
  position: absolute;
  width: 300%;
  height: 200px;
  top: -50px;
  left: -100%;
  transform: rotate(-4deg);
  overflow: hidden;
}
.nh_global_gradient {
  position: absolute;
  width: 100%;
  height: 200%;
  background: linear-gradient(300deg, var(--nh___globals___gradient1), var(--nh___globals___gradient2), var(--nh___globals___gradient3), var(--nh___globals___gradient2));
  background-size: 180% 180%;
  animation: gradient-move 18s ease 10;
}
@keyframes gradient-move {
  0% {
    background-position: 0% 50%;
  }
  50% {
    background-position: 100% 50%;
  }
  100% {
    background-position: 0% 50%;
  }
}
@media screen and (min-width: 768px) {
  :root {
    --nh___global___headerActionDirection: row;
    --nh___global___headerActionJustify: flex-end;
    --nh___globals___borderColor: #ddd;
    --nh___globals___boxShadow: rgba(100, 100, 111, 0.2) 0px 7px 29px 0px;
    --nh___globals___paddingH: 20px;
    --nh___globals___actionsHolderDirection: column;
    --nh___globals___title1___fontSize: 48px;
    --nh___globals___title1___lineHeight: 54px;
    --nh___globals___title2___fontSize: 40px;
    --nh___globals___title2___lineHeight: 48px;
    --nh___globals___text___fontSize: 21px;
    --nh___globals___display: grid;
    --nh___globals___gridColumns: repeat(12, 1fr);
    --nh___globals___gridGap: 10px;
    /* footer */
    --nh___home___footerPaddingV: 40px;
    --nh___home___footerLinkAlign: left;
    --nh___home___footerSectionAlign: flex-start;
  }
  :root .nh_footer_section-logo {
    grid-row: 1;
    grid-column: 1 / span 3;
  }
  :root .nh_footer_section-legal {
    grid-row: 1;
    grid-column: 4 / span 3;
  }
  :root .nh_footer_section-social {
    grid-row: 1;
    grid-column: 7 / span 3;
  }
  :root .nh_footer_section-contact {
    grid-row: 1;
    grid-column: 10 / span 3;
  }
}
@media screen and (min-width: 1200px) {
  .nh_lateral_cta_holder {
    display: flex;
  }
  .nh_global_footer_actions {
    display: none;
  }
}
@media screen and (min-width: 1600px) {
  :root {
    --nh___globals___paddingH: 20px;
    --nh___globals___actionsHolderDirection: row;
    --nh___globals___title1___fontSize: 72px;
    --nh___globals___title1___lineHeight: 90px;
    --nh___globals___title2___fontSize: 60px;
    --nh___globals___title2___lineHeight: 72px;
    --nh___globals___text___fontSize: 24px;
    --nh___globals___display: grid;
    --nh___globals___gridColumns: repeat(12, 1fr);
    --nh___globals___gridGap: 10px;
    /* footer */
    --nh___home___footerPaddingV: 40px;
    --nh___home___footerLinkAlign: left;
    --nh___home___footerSectionAlign: flex-start;
  }
  :root .nh_footer_section-logo {
    grid-row: 1;
    grid-column: 3 / span 2;
  }
  :root .nh_footer_section-legal {
    grid-row: 1;
    grid-column: 5 / span 2;
  }
  :root .nh_footer_section-social {
    grid-row: 1;
    grid-column: 7 / span 2;
  }
  :root .nh_footer_section-contact {
    grid-row: 1;
    grid-column: 9 / span 2;
  }
}
/* local page styles */
*,
*::before,
*::after {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
}
html {
  scroll-behavior: smooth;
  overflow-x: hidden;
}
:root {
  --or: #E8690A;
  --or2: #FF7B1F;
  --gold: #F5A41F;
  --bleu: #1D3557;
  --w: #fff;
  --bg: #000;
  --t: #F5F5F7;
  --t2: rgba(245, 245, 247, 0.65);
  --t3: rgba(245, 245, 247, 0.3);
  --line: rgba(255, 255, 255, 0.07);
  /*--headerLogo___height: 20px;*/
}
body {
  background: #000;
  color: var(--t);
  font-family: 'Inter', -apple-system, sans-serif;
  overflow-x: hidden;
  -webkit-font-smoothing: antialiased;
}
.axial_header {
  background: rgba(0, 0, 0, 0.85);
  backdrop-filter: blur(20px);
  -webkit-backdrop-filter: blur(20px);
}
/* NAV */
nav {
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  z-index: 1000;
  height: 52px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  padding: 0 clamp(16px, 4vw, 48px);
  background: rgba(0, 0, 0, 0.85);
  backdrop-filter: blur(20px);
  -webkit-backdrop-filter: blur(20px);
  border-bottom: 1px solid var(--line);
  transition: background 0.3s;
}
.nav-logo img {
  height: 30px;
}
.nav-r {
  display: flex;
  align-items: center;
  gap: 16px;
}
.nav-tel {
  font-size: 13px;
  color: var(--t3);
  text-decoration: none;
  transition: color 0.2s;
  display: none;
}
@media (min-width: 600px) {
  .nav-tel {
    display: block;
  }
}
.nav-tel:hover {
  color: var(--t);
}
.nav-cta {
  background: var(--or);
  color: #fff;
  font-size: 13px;
  font-weight: 700;
  padding: 8px 20px;
  border-radius: 980px;
  text-decoration: none;
  box-shadow: 0 0 20px rgba(232, 105, 10, 0.4);
  transition: all 0.2s;
}
.nav-cta:hover {
  background: var(--or2);
  transform: scale(1.03);
}
/* HERO */
.hero {
  min-height: 100vh;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  text-align: center;
  padding: 80px 20px 60px;
  position: relative;
  overflow: hidden;
}
.hero-mesh {
  position: absolute;
  inset: 0;
  z-index: 0;
  background: radial-gradient(ellipse 100% 80% at 50% 0%, rgba(232, 105, 10, 0.22) 0%, transparent 60%), radial-gradient(ellipse 80% 60% at 0% 100%, rgba(29, 53, 87, 0.5) 0%, transparent 55%), radial-gradient(ellipse 60% 60% at 100% 50%, rgba(245, 164, 31, 0.08) 0%, transparent 55%), #000;
  animation: meshAnim 12s ease-in-out infinite alternate;
}
@keyframes meshAnim {
  0% {
    opacity: 0.85;
  }
  100% {
    opacity: 1;
  }
}
.particles {
  position: absolute;
  inset: 0;
  z-index: 0;
  overflow: hidden;
}
.p {
  position: absolute;
  border-radius: 50%;
  pointer-events: none;
}
.hero::before {
  content: '';
  position: absolute;
  inset: 0;
  z-index: 1;
  background-image: url("data:image/svg+xml,%3Csvg viewBox='0 0 200 200' xmlns='http://www.w3.org/2000/svg'%3E%3Cfilter id='n'%3E%3CfeTurbulence type='fractalNoise' baseFrequency='0.9' numOctaves='4' stitchTiles='stitch'/%3E%3C/filter%3E%3Crect width='100%25' height='100%25' filter='url(%23n)' opacity='0.03'/%3E%3C/svg%3E");
  opacity: 0.5;
  pointer-events: none;
}
.hero-content {
  position: relative;
  z-index: 2;
  padding: 0 20px;
  max-width: 860px;
}
.hero-tag {
  display: inline-flex;
  align-items: center;
  gap: 8px;
  border: 1px solid rgba(232, 105, 10, 0.4);
  border-radius: 980px;
  padding: 5px 16px 5px 10px;
  font-size: 12px;
  font-weight: 600;
  letter-spacing: 1px;
  text-transform: uppercase;
  color: var(--or);
  background: rgba(232, 105, 10, 0.08);
  margin-bottom: 32px;
  animation: fadeUp 0.8s cubic-bezier(0.16, 1, 0.3, 1) both;
  animation-delay: 0.2s;
}
.pulse {
  width: 6px;
  height: 6px;
  border-radius: 50%;
  background: var(--or);
  box-shadow: 0 0 0 0 rgba(232, 105, 10, 0.5);
  animation: sonar 2s infinite;
}
@keyframes sonar {
  0% {
    box-shadow: 0 0 0 0 rgba(232, 105, 10, 0.6);
  }
  70% {
    box-shadow: 0 0 0 8px rgba(232, 105, 10, 0);
  }
  100% {
    box-shadow: 0 0 0 0 rgba(232, 105, 10, 0);
  }
}
@keyframes fadeUp {
  from {
    opacity: 0;
    transform: translateY(20px);
  }
  to {
    opacity: 1;
    transform: translateY(0);
  }
}
.hero-title {
  font-size: clamp(36px, 6vw, 72px);
  font-weight: 900;
  line-height: 0.9;
  letter-spacing: -4px;
  color: #fff;
  margin-bottom: 14px;
  animation: fadeUp 0.9s cubic-bezier(0.16, 1, 0.3, 1) both;
  animation-delay: 0.4s;
}
.hero-title .gr {
  background: linear-gradient(135deg, var(--or) 0%, var(--gold) 50%, var(--or2) 100%);
  -webkit-background-clip: text;
  -webkit-text-fill-color: transparent;
  background-clip: text;
  background-size: 200% auto;
  animation: grAnim 4s linear infinite;
}
@keyframes grAnim {
  0% {
    background-position: 0% center;
  }
  100% {
    background-position: 200% center;
  }
}
.hero-sub {
  font-size: clamp(17px, 2.5vw, 24px);
  font-weight: 300;
  color: var(--t2);
  margin: 16px auto 0;
  max-width: 640px;
  line-height: 1.55;
  animation: fadeUp 0.9s cubic-bezier(0.16, 1, 0.3, 1) both;
  animation-delay: 0.6s;
}
.hero-sub strong {
  color: #fff;
  font-weight: 600;
}
.hero-btns {
  display: flex;
  gap: 14px;
  justify-content: center;
  flex-wrap: wrap;
  margin-top: 44px;
  animation: fadeUp 0.9s cubic-bezier(0.16, 1, 0.3, 1) both;
  animation-delay: 0.8s;
}
.btn-glow {
  display: inline-flex;
  align-items: center;
  gap: 8px;
  background: var(--or);
  color: #fff;
  font-size: 16px;
  font-weight: 700;
  padding: 16px 36px;
  border-radius: 980px;
  text-decoration: none;
  box-shadow: 0 0 40px rgba(232, 105, 10, 0.5);
  transition: all 0.3s;
}
.btn-glow:hover {
  transform: scale(1.05);
  box-shadow: 0 0 60px rgba(232, 105, 10, 0.7);
}
.btn-ghost {
  display: inline-flex;
  align-items: center;
  gap: 8px;
  background: rgba(255, 255, 255, 0.07);
  color: var(--t);
  border: 1px solid rgba(255, 255, 255, 0.15);
  font-size: 16px;
  font-weight: 500;
  padding: 16px 36px;
  border-radius: 980px;
  text-decoration: none;
  backdrop-filter: blur(10px);
  transition: all 0.25s;
}
.btn-ghost:hover {
  background: rgba(255, 255, 255, 0.12);
}
.scroll-hint {
  position: absolute;
  bottom: 36px;
  left: 50%;
  transform: translateX(-50%);
  z-index: 2;
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 8px;
  color: var(--t3);
  font-size: 10px;
  letter-spacing: 2px;
  text-transform: uppercase;
  animation: fadeUp 0.8s both;
  animation-delay: 1.2s;
}
.sa {
  width: 20px;
  height: 20px;
  border-right: 1.5px solid rgba(255, 255, 255, 0.2);
  border-bottom: 1.5px solid rgba(255, 255, 255, 0.2);
  transform: rotate(45deg);
  animation: bounce 1.8s ease-in-out infinite;
}
@keyframes bounce {
  0%,
  100% {
    transform: rotate(45deg) translate(0, 0);
  }
  50% {
    transform: rotate(45deg) translate(4px, 4px);
  }
}
/* LAYOUT */
.w {
  max-width: 1080px;
  margin: 0 auto;
  padding: 0 clamp(20px, 5vw, 80px);
}
.sec {
  position: relative;
  overflow: hidden;
}
.py {
  padding: 120px 0;
}
.py-sm {
  padding: 72px 0;
}
.glow-or {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  pointer-events: none;
}
.sep-line {
  height: 1px;
  background: linear-gradient(90deg, transparent, rgba(232, 105, 10, 0.3), transparent);
}
/* SECTION HEADERS */
.sh {
  text-align: center;
  margin-bottom: 64px;
}
.sh-eye {
  font-size: 11px;
  font-weight: 700;
  letter-spacing: 3px;
  text-transform: uppercase;
  color: var(--or);
  display: block;
  margin-bottom: 14px;
}
.sh-title {
  font-size: clamp(36px, 5.5vw, 68px);
  font-weight: 900;
  letter-spacing: -2px;
  line-height: 0.95;
  color: #fff;
  margin-bottom: 16px;
}
.sh-title .ac {
  color: var(--or);
}
.sh-body {
  font-size: clamp(16px, 1.8vw, 20px);
  font-weight: 300;
  color: var(--t2);
  line-height: 1.65;
  max-width: 580px;
  margin: 0 auto;
}
.sh-body strong {
  color: #fff;
  font-weight: 600;
}
/* REVEAL */
.r {
  opacity: 0;
  transform: translateY(28px);
  transition: opacity 0.8s cubic-bezier(0.16, 1, 0.3, 1), transform 0.8s cubic-bezier(0.16, 1, 0.3, 1);
}
.r.in {
  opacity: 1;
  transform: translateY(0);
}
.d1 {
  transition-delay: 0.1s;
}
.d2 {
  transition-delay: 0.2s;
}
.d3 {
  transition-delay: 0.3s;
}
.d4 {
  transition-delay: 0.4s;
}
/* STAT STRIP */
.stat-strip {
  background: linear-gradient(180deg, #050505, #0A0A0A);
  border-bottom: 1px solid var(--line);
  position: relative;
  overflow: hidden;
}
.stat-strip::before {
  content: '';
  position: absolute;
  top: -80px;
  left: 50%;
  transform: translateX(-50%);
  width: 800px;
  height: 300px;
  background: radial-gradient(ellipse, rgba(232, 105, 10, 0.07) 0%, transparent 70%);
  pointer-events: none;
}
.stat-grid {
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  padding: 60px 0;
}
.stat-item {
  text-align: center;
  padding: 16px 24px;
  border-right: 1px solid var(--line);
}
.stat-item:last-child {
  border-right: none;
}
.stat-n {
  font-size: clamp(36px, 4.5vw, 58px);
  font-weight: 900;
  color: #fff;
  line-height: 1;
  letter-spacing: -2px;
  display: block;
}
.stat-n .u {
  font-size: 0.45em;
  color: var(--or);
  vertical-align: super;
}
.stat-l {
  font-size: 12px;
  color: var(--t3);
  margin-top: 8px;
  line-height: 1.5;
}
/* DOULEUR — chiffres secteur */
.douleur {
  background: linear-gradient(180deg, #000, #080810, #000);
  position: relative;
  overflow: hidden;
}
.douleur::before {
  content: '';
  position: absolute;
  inset: 0;
  background: radial-gradient(ellipse 70% 60% at 15% 50%, rgba(29, 53, 87, 0.4) 0%, transparent 65%), radial-gradient(ellipse 50% 60% at 85% 50%, rgba(232, 105, 10, 0.06) 0%, transparent 65%);
  pointer-events: none;
}
.douleur-intro {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 64px;
  align-items: center;
  margin-bottom: 72px;
}
.di-left .eyebrow {
  font-size: 11px;
  font-weight: 700;
  letter-spacing: 3px;
  text-transform: uppercase;
  color: var(--or);
  margin-bottom: 16px;
  display: block;
}
.di-left h2 {
  font-size: clamp(36px, 5vw, 60px);
  font-weight: 900;
  letter-spacing: -2px;
  color: #fff;
  line-height: 1;
  margin-bottom: 20px;
}
.di-left h2 span {
  color: var(--or);
}
.di-left p {
  font-size: 16px;
  color: var(--t2);
  line-height: 1.75;
}
.di-left p strong {
  color: #fff;
}
.crise-stats {
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  gap: 2px;
  border-radius: 16px;
  overflow: hidden;
}
.cs-item {
  background: rgba(255, 255, 255, 0.03);
  border: 1px solid var(--line);
  padding: 28px 20px;
  text-align: center;
  transition: all 0.3s;
}
.cs-item:hover {
  background: rgba(232, 105, 10, 0.06);
  border-color: rgba(232, 105, 10, 0.2);
}
.cs-n {
  font-size: clamp(32px, 4vw, 48px);
  font-weight: 900;
  line-height: 1;
  display: block;
  margin-bottom: 8px;
}
.cs-n.red {
  color: #FF3B30;
}
.cs-n.or {
  color: var(--or);
}
.cs-n.muted {
  color: rgba(255, 255, 255, 0.2);
}
.cs-l {
  font-size: 12px;
  color: var(--t3);
  line-height: 1.4;
}
.pain-points {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 2px;
  margin-top: 2px;
}
.pp-item {
  background: rgba(255, 255, 255, 0.025);
  border: 1px solid var(--line);
  padding: 32px 28px;
  position: relative;
  overflow: hidden;
  transition: all 0.35s;
}
.pp-item::after {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  height: 2px;
  background: linear-gradient(90deg, var(--or), var(--gold));
  transform: scaleX(0);
  transform-origin: left;
  transition: transform 0.4s;
}
.pp-item:hover::after {
  transform: scaleX(1);
}
.pp-item:hover {
  background: rgba(232, 105, 10, 0.04);
}
.pp-icon {
  font-size: 28px;
  margin-bottom: 16px;
  display: block;
}
.pp-title {
  font-size: 17px;
  font-weight: 700;
  color: #fff;
  margin-bottom: 8px;
}
.pp-desc {
  font-size: 14px;
  color: var(--t3);
  line-height: 1.65;
}
.pp-desc strong {
  color: var(--t2);
}
/* SOLUTION — notre réponse */
.solution {
  background: linear-gradient(180deg, #000, #030812, #000);
  position: relative;
  overflow: hidden;
}
.solution::before {
  content: '';
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  width: 900px;
  height: 600px;
  background: radial-gradient(ellipse, rgba(232, 105, 10, 0.09) 0%, transparent 65%);
  pointer-events: none;
}
.feats {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 2px;
  margin-top: 60px;
}
.feat {
  background: rgba(255, 255, 255, 0.025);
  border: 1px solid var(--line);
  padding: 36px 28px;
  transition: all 0.3s;
  position: relative;
  overflow: hidden;
}
.feat:hover {
  background: rgba(232, 105, 10, 0.06);
  border-color: rgba(232, 105, 10, 0.2);
  transform: translateY(-4px);
}
.feat-icon {
  font-size: 28px;
  margin-bottom: 16px;
  display: block;
}
.feat-title {
  font-size: 16px;
  font-weight: 700;
  color: #fff;
  margin-bottom: 8px;
}
.feat-desc {
  font-size: 13px;
  color: var(--t3);
  line-height: 1.65;
}
.feat-desc strong {
  color: var(--t2);
}
/* ANCHORING */
.anchor-wrap {
  display: grid;
  grid-template-columns: 1fr 48px 1fr;
  align-items: center;
  max-width: 800px;
  margin: 56px auto 0;
}
.anchor-box {
  border-radius: 20px;
  padding: 40px 36px;
  text-align: center;
}
.anchor-box.bad {
  background: rgba(255, 255, 255, 0.04);
  border: 1px solid var(--line);
}
.anchor-box.good {
  background: linear-gradient(145deg, rgba(232, 105, 10, 0.18), rgba(232, 105, 10, 0.06));
  border: 1px solid rgba(232, 105, 10, 0.4);
  box-shadow: 0 0 80px rgba(232, 105, 10, 0.15), inset 0 1px 0 rgba(255, 255, 255, 0.1);
  transform: scale(1.04);
}
.ab-label {
  font-size: 11px;
  font-weight: 700;
  letter-spacing: 2px;
  text-transform: uppercase;
  display: block;
  margin-bottom: 12px;
}
.anchor-box.bad .ab-label {
  color: var(--t3);
}
.anchor-box.good .ab-label {
  color: var(--or);
}
.ab-price {
  font-size: clamp(48px, 6vw, 72px);
  font-weight: 900;
  letter-spacing: -3px;
  line-height: 1;
  display: block;
  margin-bottom: 10px;
}
.anchor-box.bad .ab-price {
  color: rgba(255, 255, 255, 0.2);
  text-decoration: line-through;
}
.anchor-box.good .ab-price {
  color: #fff;
}
.ab-sub {
  font-size: 13px;
  line-height: 1.5;
}
.anchor-box.bad .ab-sub {
  color: var(--t3);
}
.anchor-box.good .ab-sub {
  color: rgba(255, 255, 255, 0.7);
}
.anchor-vs {
  text-align: center;
  font-size: 13px;
  font-weight: 700;
  color: var(--t3);
}
/* LEAD CARD */
.lead-showcase {
  max-width: 700px;
  margin: 56px auto 0;
  background: rgba(255, 255, 255, 0.04);
  border: 1px solid rgba(255, 255, 255, 0.1);
  border-radius: 24px;
  overflow: hidden;
  box-shadow: 0 40px 100px rgba(0, 0, 0, 0.5);
}
.ls-bar {
  background: rgba(232, 105, 10, 0.15);
  border-bottom: 1px solid rgba(232, 105, 10, 0.2);
  padding: 14px 24px;
  display: flex;
  align-items: center;
  gap: 8px;
}
.ld {
  width: 10px;
  height: 10px;
  border-radius: 50%;
}
.ld.r {
  background: #FF5F56;
}
.ld.y {
  background: #FFBD2E;
}
.ld.g {
  background: #27C93F;
}
.ls-tag-r {
  font-size: 11px;
  font-weight: 700;
  letter-spacing: 1.5px;
  text-transform: uppercase;
  color: var(--or);
  margin-left: auto;
}
.ls-body {
  padding: 32px 28px;
}
.ls-grid {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 22px;
  margin-bottom: 28px;
}
.lf-k {
  font-size: 10px;
  font-weight: 600;
  letter-spacing: 2px;
  text-transform: uppercase;
  color: var(--t3);
  margin-bottom: 5px;
}
.lf-v {
  font-size: 16px;
  font-weight: 600;
  color: #fff;
}
.lf-v.money {
  color: var(--or);
  font-size: 22px;
  font-weight: 800;
}
.lf-v.ok {
  color: #34D399;
}
.lf-v.blur {
  filter: blur(4px);
  color: var(--t3);
  font-style: italic;
  cursor: not-allowed;
}
.ls-foot {
  border-top: 1px solid var(--line);
  padding-top: 22px;
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: 16px;
  flex-wrap: wrap;
}
.ls-foot p {
  font-size: 14px;
  color: var(--t2);
}
.ls-foot p strong {
  color: #fff;
}
/* PACKS */
.packs-grid {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 16px;
  margin-top: 56px;
}
.pack {
  border-radius: 20px;
  padding: 36px 28px;
  position: relative;
  overflow: hidden;
  transition: all 0.3s cubic-bezier(0.16, 1, 0.3, 1);
  border: 1px solid var(--line);
  background: rgba(255, 255, 255, 0.03);
}
.pack:hover {
  transform: translateY(-8px);
  border-color: rgba(255, 255, 255, 0.15);
  background: rgba(255, 255, 255, 0.06);
}
.pack.star {
  border-color: rgba(232, 105, 10, 0.5);
  background: linear-gradient(145deg, rgba(232, 105, 10, 0.12), rgba(232, 105, 10, 0.04));
  box-shadow: 0 0 0 1px rgba(232, 105, 10, 0.2), 0 40px 80px rgba(232, 105, 10, 0.12);
}
.pack.star:hover {
  box-shadow: 0 0 0 1px rgba(232, 105, 10, 0.35), 0 50px 100px rgba(232, 105, 10, 0.18);
}
.pack-glow {
  position: absolute;
  top: -60px;
  right: -60px;
  width: 200px;
  height: 200px;
  border-radius: 50%;
  background: radial-gradient(circle, rgba(232, 105, 10, 0.12), transparent 70%);
  pointer-events: none;
}
.pack-badge {
  display: inline-block;
  background: var(--or);
  color: #fff;
  font-size: 10px;
  font-weight: 700;
  letter-spacing: 1.5px;
  text-transform: uppercase;
  padding: 5px 14px;
  border-radius: 980px;
  margin-bottom: 18px;
  box-shadow: 0 4px 16px rgba(232, 105, 10, 0.4);
}
.pack-tier {
  font-size: 12px;
  font-weight: 700;
  letter-spacing: 2px;
  text-transform: uppercase;
  color: var(--t3);
  margin-bottom: 10px;
}
.pack-qty {
  font-size: 72px;
  font-weight: 900;
  color: #fff;
  line-height: 1;
  letter-spacing: -4px;
  margin-bottom: 4px;
}
.pack-qty-sub {
  font-size: 13px;
  color: var(--t3);
  margin-bottom: 24px;
}
.pack-list {
  list-style: none;
  display: flex;
  flex-direction: column;
  gap: 9px;
  padding: 20px 0;
  border-top: 1px solid var(--line);
  border-bottom: 1px solid var(--line);
  margin-bottom: 20px;
}
.pack-list li {
  display: flex;
  align-items: center;
  gap: 9px;
  font-size: 13px;
  color: var(--t2);
}
.pack-list li::before {
  content: '✓';
  color: var(--or);
  font-weight: 700;
  font-size: 12px;
  flex-shrink: 0;
}
.pack-price {
  font-size: 34px;
  font-weight: 800;
  color: #fff;
  letter-spacing: -1px;
}
.pack-unit {
  font-size: 12px;
  color: var(--t3);
  margin-bottom: 16px;
}
.roi-box {
  border-radius: 10px;
  padding: 14px 16px;
  margin-bottom: 18px;
}
.roi-box.dark {
  background: rgba(255, 255, 255, 0.04);
  border: 1px solid rgba(255, 255, 255, 0.07);
}
.roi-box.orange {
  background: rgba(232, 105, 10, 0.1);
  border: 1px solid rgba(232, 105, 10, 0.25);
}
.roi-label {
  font-size: 10px;
  font-weight: 700;
  letter-spacing: 1.5px;
  text-transform: uppercase;
  color: var(--t3);
  margin-bottom: 8px;
}
.roi-box.orange .roi-label {
  color: rgba(232, 105, 10, 0.8);
}
.roi-row {
  display: flex;
  justify-content: space-between;
  align-items: center;
  gap: 8px;
}
.roi-ca {
  font-size: 22px;
  font-weight: 800;
  color: #fff;
  letter-spacing: -0.5px;
}
.roi-ca-sub {
  font-size: 11px;
  color: var(--t3);
  margin-bottom: 3px;
}
.roi-mult {
  font-size: 26px;
  font-weight: 900;
  color: var(--or);
  letter-spacing: -1px;
}
.roi-mult-sub {
  font-size: 11px;
  color: var(--t3);
  margin-bottom: 3px;
  text-align: right;
}
.roi-note {
  font-size: 10px;
  color: rgba(255, 255, 255, 0.2);
  margin-top: 8px;
  padding-top: 8px;
  border-top: 1px solid rgba(255, 255, 255, 0.06);
  line-height: 1.4;
}
.pack-btn {
  display: block;
  width: 100%;
  text-align: center;
  font-family: 'Inter', sans-serif;
  font-size: 14px;
  font-weight: 700;
  padding: 14px;
  border-radius: 980px;
  border: none;
  cursor: pointer;
  transition: all 0.2s;
  background: rgba(255, 255, 255, 0.08);
  color: var(--t);
}
.pack.star .pack-btn {
  background: var(--or);
  color: #fff;
  box-shadow: 0 8px 28px rgba(232, 105, 10, 0.4);
}
.pack-btn:hover {
  opacity: 0.85;
  transform: scale(1.02);
}
.packs-note {
  font-size: 12px;
  color: var(--t3);
  text-align: center;
  margin-top: 18px;
}
/* TEMOIGNAGES */
.testi-grid {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 16px;
  margin-top: 56px;
}
.testi {
  background: rgba(255, 255, 255, 0.03);
  border: 1px solid var(--line);
  border-radius: 16px;
  padding: 28px;
  transition: all 0.3s;
  position: relative;
  overflow: hidden;
}
.testi::before {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  height: 2px;
  background: linear-gradient(90deg, var(--or), var(--gold));
  transform: scaleX(0);
  transform-origin: left;
  transition: transform 0.4s;
}
.testi:hover::before {
  transform: scaleX(1);
}
.testi:hover {
  background: rgba(232, 105, 10, 0.04);
  border-color: rgba(232, 105, 10, 0.2);
}
.testi-stars {
  color: var(--or);
  font-size: 14px;
  letter-spacing: 2px;
  margin-bottom: 14px;
  display: block;
}
.testi-text {
  font-size: 15px;
  color: var(--t2);
  line-height: 1.7;
  font-style: italic;
  margin-bottom: 20px;
}
.testi-text strong {
  color: #fff;
  font-style: normal;
}
.testi-author {
  display: flex;
  align-items: center;
  gap: 12px;
}
.testi-av {
  width: 40px;
  height: 40px;
  border-radius: 50%;
  background: linear-gradient(135deg, var(--or), var(--gold));
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 15px;
  font-weight: 800;
  color: #fff;
  flex-shrink: 0;
}
.testi-name {
  font-size: 14px;
  font-weight: 700;
  color: #fff;
}
.testi-role {
  font-size: 12px;
  color: var(--t3);
}
/* BENTO MÉTIERS */
.bento {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 2px;
  margin-top: 56px;
  border-radius: 20px;
  overflow: hidden;
}
.bento-cell {
  background: rgba(255, 255, 255, 0.025);
  border: 1px solid var(--line);
  padding: 36px 32px;
  transition: all 0.35s;
  cursor: default;
  position: relative;
  overflow: hidden;
}
.bento-cell::after {
  content: '';
  position: absolute;
  inset: 0;
  background: linear-gradient(135deg, rgba(232, 105, 10, 0.1), transparent 60%);
  opacity: 0;
  transition: opacity 0.4s;
}
.bento-cell:hover::after {
  opacity: 1;
}
.bento-cell:hover {
  border-color: rgba(232, 105, 10, 0.2);
}
.b-icon {
  font-size: 36px;
  margin-bottom: 16px;
  display: block;
}
.b-name {
  font-size: 18px;
  font-weight: 700;
  color: #fff;
  margin-bottom: 6px;
}
.b-desc {
  font-size: 13px;
  color: var(--t3);
  line-height: 1.6;
  margin-bottom: 12px;
}
.b-panier {
  display: inline-block;
  font-size: 11px;
  font-weight: 700;
  color: var(--or);
  background: rgba(232, 105, 10, 0.1);
  border: 1px solid rgba(232, 105, 10, 0.2);
  padding: 3px 10px;
  border-radius: 980px;
}
/* PROCESS TIMELINE */
.timeline {
  max-width: 760px;
  margin: 56px auto 0;
}
.tl-step {
  display: grid;
  grid-template-columns: 56px 1fr;
  padding: 40px 0;
  border-bottom: 1px solid var(--line);
  transition: all 0.3s;
}
.tl-step:last-child {
  border-bottom: none;
}
.tl-step:hover .tl-n {
  -webkit-text-fill-color: var(--or);
}
.tl-n {
  font-size: clamp(44px, 5vw, 60px);
  font-weight: 900;
  line-height: 1;
  letter-spacing: -3px;
  background: linear-gradient(135deg, rgba(255, 255, 255, 0.12), rgba(255, 255, 255, 0.04));
  -webkit-background-clip: text;
  -webkit-text-fill-color: transparent;
  background-clip: text;
  transition: all 0.3s;
  padding-top: 4px;
}
.tl-c {
  padding-left: 28px;
}
.tl-title {
  font-size: clamp(18px, 2.2vw, 24px);
  font-weight: 700;
  color: rgba(255, 255, 255, 0.8);
  margin-bottom: 8px;
  letter-spacing: -0.3px;
  transition: color 0.3s;
}
.tl-step:hover .tl-title {
  color: #fff;
}
.tl-desc {
  font-size: 14px;
  color: var(--t3);
  line-height: 1.7;
  max-width: 480px;
}
.tl-desc strong {
  color: rgba(255, 255, 255, 0.7);
}
/* COMPARATIF */
.compar {
  border-radius: 20px;
  overflow: hidden;
  border: 1px solid var(--line);
  margin-top: 56px;
}
.cmp-head {
  display: grid;
  grid-template-columns: 1fr 1fr;
}
.cmp-h {
  padding: 20px 36px;
  font-size: 14px;
  font-weight: 700;
}
.cmp-h.bad {
  background: rgba(255, 255, 255, 0.03);
  color: var(--t3);
}
.cmp-h.good {
  background: var(--or);
  color: #fff;
}
.cmp-row {
  display: grid;
  grid-template-columns: 1fr 1fr;
}
.cmp-cell {
  padding: 16px 36px;
  font-size: 14px;
  border-top: 1px solid var(--line);
  display: flex;
  align-items: flex-start;
  gap: 10px;
  line-height: 1.5;
}
.cmp-cell.bad {
  background: rgba(255, 255, 255, 0.015);
  color: var(--t3);
}
.cmp-cell.good {
  background: rgba(232, 105, 10, 0.04);
  color: rgba(255, 255, 255, 0.8);
}
.cmp-cell i {
  flex-shrink: 0;
  font-style: normal;
  font-weight: 700;
}
.cmp-cell.bad i {
  color: #EF4444;
}
.cmp-cell.good i {
  color: var(--or);
}
/* ROI VISUEL */
.roi-visual {
  background: rgba(255, 255, 255, 0.03);
  border: 1px solid var(--line);
  border-radius: 20px;
  padding: 48px;
  margin-top: 56px;
  text-align: center;
  position: relative;
  overflow: hidden;
}
.roi-visual::before {
  content: '';
  position: absolute;
  top: -100px;
  left: 50%;
  transform: translateX(-50%);
  width: 600px;
  height: 400px;
  background: radial-gradient(ellipse, rgba(232, 105, 10, 0.08) 0%, transparent 65%);
  pointer-events: none;
}
.roi-flow {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 0;
  flex-wrap: wrap;
  margin: 36px 0;
  position: relative;
  z-index: 1;
}
.roi-step {
  text-align: center;
  padding: 0 24px;
}
.roi-step .rs-n {
  font-size: clamp(28px, 4vw, 48px);
  font-weight: 900;
  color: #fff;
  line-height: 1;
  display: block;
  letter-spacing: -1px;
}
.roi-step .rs-l {
  font-size: 12px;
  color: var(--t3);
  margin-top: 6px;
  line-height: 1.4;
}
.roi-arrow {
  font-size: 20px;
  color: var(--or);
  padding: 0 8px;
  flex-shrink: 0;
  opacity: 0.6;
}
.roi-final .rs-n {
  color: var(--or);
  font-size: clamp(40px, 5vw, 64px);
}
.roi-note {
  font-size: 13px;
  color: var(--t3);
  position: relative;
  z-index: 1;
}
/* FOMO BAND */
.fomo-band {
  padding: 100px 40px;
  text-align: center;
  position: relative;
  overflow: hidden;
  background: linear-gradient(180deg, #000, #0A0A0A, #000);
}
.fomo-band::before {
  content: '';
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  width: 700px;
  height: 500px;
  border-radius: 50%;
  background: radial-gradient(circle, rgba(232, 105, 10, 0.15) 0%, transparent 70%);
  animation: fbPulse 4s ease-in-out infinite alternate;
}
@keyframes fbPulse {
  0% {
    transform: translate(-50%, -50%) scale(1);
  }
  100% {
    transform: translate(-50%, -50%) scale(1.2);
  }
}
.fomo-title {
  position: relative;
  z-index: 1;
  font-size: clamp(28px, 4.5vw, 52px);
  font-weight: 900;
  letter-spacing: -2px;
  color: #fff;
  line-height: 1.05;
  margin-bottom: 18px;
}
.fomo-body {
  position: relative;
  z-index: 1;
  font-size: 17px;
  color: var(--t2);
  max-width: 580px;
  margin: 0 auto 36px;
  line-height: 1.65;
}
.fomo-body strong {
  color: #fff;
}
.fomo-cta {
  position: relative;
  z-index: 1;
  display: inline-flex;
  align-items: center;
  gap: 10px;
  background: #fff;
  color: #000;
  font-size: 16px;
  font-weight: 800;
  padding: 16px 40px;
  border-radius: 980px;
  text-decoration: none;
  box-shadow: 0 8px 40px rgba(255, 255, 255, 0.15);
  transition: all 0.2s;
}
.fomo-cta:hover {
  transform: scale(1.04);
}
/* FAQ */
.faq-list {
  max-width: 760px;
  margin: 56px auto 0;
}
.faq-item {
  border-bottom: 1px solid var(--line);
  padding: 0;
}
.faq-q {
  display: flex;
  align-items: center;
  justify-content: space-between;
  gap: 20px;
  padding: 24px 0;
  cursor: pointer;
  transition: color 0.2s;
}
.faq-q:hover {
  color: var(--or);
}
.faq-q span:first-child {
  font-size: 16px;
  font-weight: 600;
  color: #fff;
  line-height: 1.4;
  flex: 1;
  transition: color 0.2s;
}
.faq-q:hover span:first-child {
  color: var(--or);
}
.faq-icon {
  font-size: 22px;
  color: var(--or);
  flex-shrink: 0;
  transition: transform 0.35s;
  line-height: 1;
  font-weight: 300;
}
.faq-item.open .faq-icon {
  transform: rotate(45deg);
}
.faq-a {
  max-height: 0;
  overflow: hidden;
  transition: max-height 0.45s ease, padding 0.35s;
}
.faq-item.open .faq-a {
  max-height: 500px;
  padding-bottom: 24px;
}
.faq-a p {
  font-size: 15px;
  color: var(--t2);
  line-height: 1.75;
}
.faq-a p strong {
  color: #fff;
}
.faq-wa {
  text-align: center;
  margin-top: 48px;
  padding: 28px;
  background: rgba(255, 255, 255, 0.025);
  border: 1px solid var(--line);
  border-radius: 16px;
}
.faq-wa p {
  font-size: 15px;
  color: var(--t2);
  margin-bottom: 16px;
}
.btn-wa {
  display: inline-flex;
  align-items: center;
  gap: 10px;
  background: #25D366;
  color: #fff;
  font-size: 14px;
  font-weight: 700;
  padding: 13px 28px;
  border-radius: 980px;
  text-decoration: none;
  box-shadow: 0 8px 24px rgba(37, 211, 102, 0.3);
  transition: all 0.2s;
}
.btn-wa:hover {
  opacity: 0.9;
  transform: scale(1.03);
}
/* FORM */
.form-sec {
  background: linear-gradient(180deg, #000 0%, #030C1A 50%, #000 100%);
  padding: 120px 40px;
  position: relative;
  overflow: hidden;
}
.form-sec::before {
  content: '';
  position: absolute;
  inset: 0;
  background: radial-gradient(ellipse 70% 60% at 50% 50%, rgba(29, 53, 87, 0.3) 0%, transparent 65%);
  pointer-events: none;
}
.form-sec::after {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  height: 1px;
  background: linear-gradient(90deg, transparent, rgba(29, 53, 87, 0.6), transparent);
}
.form-wrap {
  max-width: 560px;
  margin: 0 auto;
  position: relative;
  z-index: 1;
}
.form-hd {
  text-align: center;
  margin-bottom: 40px;
}
.form-hd .eye {
  font-size: 11px;
  font-weight: 700;
  letter-spacing: 2px;
  text-transform: uppercase;
  color: var(--or);
  display: block;
  margin-bottom: 12px;
}
.form-hd h2 {
  font-size: clamp(32px, 4.5vw, 52px);
  font-weight: 900;
  letter-spacing: -2px;
  color: #fff;
  line-height: 1;
  margin-bottom: 10px;
}
.form-hd h2 span {
  color: var(--or);
}
.form-hd p {
  font-size: 15px;
  color: var(--t3);
}
.form-card {
  background: rgba(255, 255, 255, 0.03);
  border: 1px solid rgba(255, 255, 255, 0.1);
  border-radius: 24px;
  padding: 44px 40px;
  box-shadow: 0 40px 100px rgba(0, 0, 0, 0.5);
}
.fc-steps {
  display: flex;
  align-items: center;
  gap: 8px;
  margin-bottom: 28px;
  justify-content: center;
}
.fc-dot {
  width: 30px;
  height: 30px;
  border-radius: 50%;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 13px;
  font-weight: 700;
  transition: all 0.3s;
}
.fc-dot.on {
  background: var(--or);
  color: #fff;
  box-shadow: 0 0 20px rgba(232, 105, 10, 0.5);
}
.fc-dot.ok {
  background: #10B981;
  color: #fff;
}
.fc-dot.off {
  background: rgba(255, 255, 255, 0.06);
  color: var(--t3);
  border: 1px solid var(--line);
}
.fc-line {
  flex: 1;
  height: 1.5px;
  border-radius: 2px;
  background: var(--line);
  transition: background 0.35s;
}
.fc-line.done {
  background: var(--or);
}
#pkbox {
  display: none;
  align-items: center;
  justify-content: space-between;
  gap: 12px;
  background: rgba(232, 105, 10, 0.1);
  border: 1px solid rgba(232, 105, 10, 0.3);
  border-radius: 12px;
  padding: 14px 18px;
  margin-bottom: 24px;
}
#pkbox.show {
  display: flex;
}
.pk-l {
  font-size: 10px;
  font-weight: 700;
  letter-spacing: 1.5px;
  text-transform: uppercase;
  color: var(--t3);
  margin-bottom: 3px;
}
.pk-v {
  font-size: 14px;
  font-weight: 700;
  color: var(--or);
}
#pkbox button {
  font-size: 12px;
  color: var(--t3);
  background: none;
  border: none;
  cursor: pointer;
  text-decoration: underline;
  font-family: 'Inter', sans-serif;
}
.fc-title {
  font-size: 22px;
  font-weight: 800;
  color: #fff;
  margin-bottom: 5px;
  letter-spacing: -0.5px;
}
.fc-sub {
  font-size: 13px;
  color: var(--t3);
  margin-bottom: 22px;
  line-height: 1.5;
}
.fc-sub strong {
  color: var(--or);
}
.fi {
  display: flex;
  flex-direction: column;
  gap: 5px;
  margin-bottom: 12px;
}
.fi label {
  font-size: 10px;
  font-weight: 700;
  letter-spacing: 1.5px;
  text-transform: uppercase;
  color: var(--t3);
}
.fi input,
.fi select {
  background: rgba(255, 255, 255, 0.05);
  border: 1.5px solid rgba(255, 255, 255, 0.1);
  border-radius: 12px;
  color: #fff;
  font-family: 'Inter', sans-serif;
  font-size: 15px;
  padding: 13px 16px;
  outline: none;
  width: 100%;
  transition: all 0.2s;
}
.fi input:focus,
.fi select:focus {
  border-color: var(--or);
  background: rgba(232, 105, 10, 0.06);
  box-shadow: 0 0 0 3px rgba(232, 105, 10, 0.12);
}
.fi input::placeholder {
  color: rgba(255, 255, 255, 0.2);
}
.mg {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 8px;
  margin-bottom: 18px;
}
.mo {
  position: relative;
}
.mo input {
  position: absolute;
  opacity: 0;
  width: 0;
  height: 0;
}
.mo label {
  display: flex;
  align-items: center;
  gap: 8px;
  background: rgba(255, 255, 255, 0.04);
  border: 1.5px solid var(--line);
  border-radius: 12px;
  padding: 11px 14px;
  cursor: pointer;
  font-size: 13px;
  color: var(--t3);
  font-weight: 500;
  transition: all 0.2s;
}
.mo label:hover {
  border-color: rgba(255, 255, 255, 0.2);
  color: var(--t);
}
.mo input:checked + label {
  border-color: var(--or);
  color: var(--or);
  background: rgba(232, 105, 10, 0.08);
  font-weight: 700;
}
.mo.full {
  grid-column: 1/-1;
}
.zone-ok {
  background: rgba(16, 185, 129, 0.1);
  border: 1px solid rgba(16, 185, 129, 0.3);
  border-radius: 12px;
  padding: 16px 20px;
  margin-bottom: 22px;
}
.zone-ok strong {
  display: block;
  color: #34D399;
  font-size: 15px;
  font-weight: 700;
  margin-bottom: 3px;
}
.zone-ok p {
  font-size: 12px;
  color: rgba(255, 255, 255, 0.4);
}
.btn-submit {
  width: 100%;
  background: var(--or);
  color: #fff;
  font-family: 'Inter', sans-serif;
  font-size: 16px;
  font-weight: 700;
  border: none;
  border-radius: 980px;
  padding: 17px;
  cursor: pointer;
  transition: all 0.25s;
  box-shadow: 0 8px 28px rgba(232, 105, 10, 0.4);
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 8px;
}
.btn-submit:hover {
  background: var(--or2);
  transform: translateY(-2px);
  box-shadow: 0 12px 36px rgba(232, 105, 10, 0.5);
}
.fc-legal {
  font-size: 11px;
  color: var(--t3);
  text-align: center;
  margin-top: 12px;
  line-height: 1.6;
}
.fc-legal strong {
  color: #EF4444;
}
.guarantie {
  display: flex;
  align-items: center;
  gap: 10px;
  background: rgba(255, 255, 255, 0.03);
  border: 1px solid var(--line);
  border-radius: 10px;
  padding: 14px 18px;
  margin-top: 16px;
}
.guarantie .gi {
  font-size: 20px;
  flex-shrink: 0;
}
.guarantie p {
  font-size: 13px;
  color: var(--t3);
  line-height: 1.5;
}
.guarantie p strong {
  color: var(--t2);
}
/* OUTRO */
.outro {
  min-height: 80vh;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  text-align: center;
  position: relative;
  overflow: hidden;
  background: #000;
}
.outro-bg {
  position: absolute;
  inset: 0;
  background: radial-gradient(ellipse 80% 60% at 50% 60%, rgba(232, 105, 10, 0.18) 0%, transparent 65%), #000;
  animation: outroPulse 6s ease-in-out infinite alternate;
}
@keyframes outroPulse {
  0% {
    opacity: 0.7;
  }
  100% {
    opacity: 1;
  }
}
.outro-content {
  position: relative;
  z-index: 1;
  padding: 0 20px;
}
.outro-title {
  font-size: clamp(48px, 9vw, 110px);
  font-weight: 900;
  letter-spacing: -4px;
  color: #fff;
  line-height: 0.9;
  margin-bottom: 20px;
}
.outro-title .gr {
  background: linear-gradient(135deg, var(--or), var(--gold), var(--or2));
  -webkit-background-clip: text;
  -webkit-text-fill-color: transparent;
  background-clip: text;
  background-size: 200% auto;
  animation: grAnim 3s linear infinite;
}
.outro-sub {
  font-size: 20px;
  color: var(--t3);
  margin-bottom: 48px;
  font-weight: 300;
}
.outro-btn {
  display: inline-flex;
  align-items: center;
  gap: 12px;
  background: var(--or);
  color: #fff;
  font-size: 18px;
  font-weight: 700;
  padding: 20px 52px;
  border-radius: 980px;
  text-decoration: none;
  box-shadow: 0 0 60px rgba(232, 105, 10, 0.5), 0 16px 48px rgba(232, 105, 10, 0.3);
  transition: all 0.3s;
}
.outro-btn:hover {
  transform: scale(1.05);
  box-shadow: 0 0 90px rgba(232, 105, 10, 0.7);
}
/* FOOTER */
footer {
  background: #000;
  border-top: 1px solid var(--line);
  padding: 40px clamp(20px, 5vw, 80px);
}
.footer-inner {
  max-width: 1080px;
  margin: 0 auto;
  display: flex;
  align-items: center;
  justify-content: space-between;
  flex-wrap: wrap;
  gap: 16px;
}
footer p {
  font-size: 13px;
  color: rgba(255, 255, 255, 0.2);
}
footer a {
  color: rgba(255, 255, 255, 0.2);
  text-decoration: none;
  transition: color 0.2s;
}
footer a:hover {
  color: var(--or);
}
/* WA */
.wa {
  position: fixed;
  bottom: 28px;
  right: 28px;
  z-index: 999;
  width: 54px;
  height: 54px;
  border-radius: 50%;
  background: #25D366;
  display: flex;
  align-items: center;
  justify-content: center;
  box-shadow: 0 8px 32px rgba(37, 211, 102, 0.5);
  transition: transform 0.2s;
  text-decoration: none;
}
.wa:hover {
  transform: scale(1.1);
}
.wa svg {
  width: 26px;
  height: 26px;
  fill: #fff;
}
.wap {
  position: absolute;
  top: 0;
  right: 0;
  width: 14px;
  height: 14px;
  background: var(--or);
  border-radius: 50%;
  border: 2px solid #000;
  animation: waPing 2s infinite;
}
@keyframes waPing {
  0%,
  100% {
    transform: scale(1);
  }
  50% {
    transform: scale(1.6);
    opacity: 0.5;
  }
}
/* RESPONSIVE */
@media (max-width: 860px) {
  .stat-grid {
    grid-template-columns: 1fr 1fr;
  }
  .stat-item:nth-child(2) {
    border-right: none;
  }
  .douleur-intro {
    grid-template-columns: 1fr;
    gap: 40px;
  }
  .crise-stats {
    grid-template-columns: 1fr 1fr;
  }
  .pain-points {
    grid-template-columns: 1fr;
  }
  .feats {
    grid-template-columns: 1fr 1fr;
  }
  .anchor-wrap {
    grid-template-columns: 1fr;
    gap: 16px;
  }
  .anchor-vs,
  .anchor-box.good {
    transform: none;
  }
  .packs-grid {
    grid-template-columns: 1fr;
  }
  .testi-grid {
    grid-template-columns: 1fr;
  }
  .bento {
    grid-template-columns: 1fr 1fr;
  }
  .cmp-head {
    grid-template-columns: 1fr;
  }
  .cmp-h.bad {
    display: none;
  }
  .cmp-row {
    grid-template-columns: 1fr;
  }
  .cmp-cell.bad {
    display: none;
  }
  .ls-grid {
    grid-template-columns: 1fr 1fr;
  }
  .roi-flow {
    gap: 8px;
  }
  .roi-step {
    padding: 0 12px;
  }
  .mg {
    grid-template-columns: 1fr;
  }
  .mo.full {
    grid-column: 1;
  }
  .form-card {
    padding: 32px 24px;
  }
}
@media (max-width: 580px) {
  .bento {
    grid-template-columns: 1fr;
  }
  .feats {
    grid-template-columns: 1fr;
  }
  .ls-grid {
    grid-template-columns: 1fr;
  }
  .hero-title {
    letter-spacing: -2px;
  }
}
